CVS commit: src/sys/dev/pci

2013-04-11 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Thu Apr 11 10:10:42 UTC 2013

Modified Files:
src/sys/dev/pci: if_bgereg.h

Log Message:
Add BGE_PCIMISCCTL_PCISTATE_RW in BGE_INIT. It's required to set the PCISTATE
register correctly.


To generate a diff of this commit:
cvs rdiff -u -r1.72 -r1.73 src/sys/dev/pci/if_bgereg.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/pci/if_bgereg.h
diff -u src/sys/dev/pci/if_bgereg.h:1.72 src/sys/dev/pci/if_bgereg.h:1.73
--- src/sys/dev/pci/if_bgereg.h:1.72	Mon Apr  8 15:55:58 2013
+++ src/sys/dev/pci/if_bgereg.h	Thu Apr 11 10:10:41 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_bgereg.h,v 1.72 2013/04/08 15:55:58 msaitoh Exp $	*/
+/*	$NetBSD: if_bgereg.h,v 1.73 2013/04/11 10:10:41 msaitoh Exp $	*/
 /*
  * Copyright (c) 2001 Wind River Systems
  * Copyright (c) 1997, 1998, 1999, 2001
@@ -275,7 +275,8 @@
 
 #define BGE_INIT \
 	(BGE_HIF_SWAP_OPTIONS|BGE_PCIMISCCTL_CLEAR_INTA| \
-	 BGE_PCIMISCCTL_MASK_PCI_INTR|BGE_PCIMISCCTL_INDIRECT_ACCESS)
+	 BGE_PCIMISCCTL_MASK_PCI_INTR|BGE_PCIMISCCTL_INDIRECT_ACCESS| \
+	 BGE_PCIMISCCTL_PCISTATE_RW)
 
 #define BGE_CHIPID_TIGON_I		0x4000
 #define BGE_CHIPID_TIGON_II		0x6000



CVS commit: src/sys/dev/pci

2013-04-11 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Thu Apr 11 10:12:48 UTC 2013

Modified Files:
src/sys/dev/pci: if_bgereg.h

Log Message:
Fix typo in comment.


To generate a diff of this commit:
cvs rdiff -u -r1.73 -r1.74 src/sys/dev/pci/if_bgereg.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/pci/if_bgereg.h
diff -u src/sys/dev/pci/if_bgereg.h:1.73 src/sys/dev/pci/if_bgereg.h:1.74
--- src/sys/dev/pci/if_bgereg.h:1.73	Thu Apr 11 10:10:41 2013
+++ src/sys/dev/pci/if_bgereg.h	Thu Apr 11 10:12:48 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_bgereg.h,v 1.73 2013/04/11 10:10:41 msaitoh Exp $	*/
+/*	$NetBSD: if_bgereg.h,v 1.74 2013/04/11 10:12:48 msaitoh Exp $	*/
 /*
  * Copyright (c) 2001 Wind River Systems
  * Copyright (c) 1997, 1998, 1999, 2001
@@ -430,7 +430,7 @@
 
 /*
  * PCI state register -- note, this register is read only
- * unless the PCISTATE_WR bit of the PCI Misc. Host Control
+ * unless the PCISTATE_RW bit of the PCI Misc. Host Control
  * register is set.
  */
 #define BGE_PCISTATE_FORCE_RESET	0x0001



CVS commit: src/sys/dev/pci

2013-04-11 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Thu Apr 11 11:24:08 UTC 2013

Modified Files:
src/sys/dev/pci: if_bge.c

Log Message:
Update comments from 57XX-PG105-R.pdf and 5718-PG106-R.pdf.
No functional change.


To generate a diff of this commit:
cvs rdiff -u -r1.235 -r1.236 src/sys/dev/pci/if_bge.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/m68k/fpe/fpu_emulate.h
diff -u src/sys/arch/m68k/fpe/fpu_emulate.h:1.22 src/sys/arch/m68k/fpe/fpu_emulate.h:1.23
--- src/sys/arch/m68k/fpe/fpu_emulate.h:1.22	Tue Mar 26 11:30:20 2013
+++ src/sys/arch/m68k/fpe/fpu_emulate.h	Thu Apr 11 13:27:11 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: fpu_emulate.h,v 1.22 2013/03/26 11:30:20 isaki Exp $	*/
+/*	$NetBSD: fpu_emulate.h,v 1.23 2013/04/11 13:27:11 isaki Exp $	*/
 
 /*
  * Copyright (c) 1995 Gordon Ross
@@ -253,6 +253,11 @@ struct fpn *fpu_sincos_taylor(struct fpe
  */
 /* return values from constant rom */
 struct fpn *fpu_const(struct fpn *, uint32_t);
+#define FPU_CONST_PI	(0x00)	/* pi */
+#define FPU_CONST_LN_2	(0x30)	/* ln(2) */
+#define FPU_CONST_LN_10	(0x31)	/* ln(10) */
+#define FPU_CONST_1 	(0x32)	/* 1.0 */
+
 /* update exceptions and FPSR */
 int fpu_upd_excp(struct fpemu *);
 uint32_t fpu_upd_fpsr(struct fpemu *, struct fpn *);

Index: src/sys/arch/m68k/fpe/fpu_hyperb.c
diff -u src/sys/arch/m68k/fpe/fpu_hyperb.c:1.7 src/sys/arch/m68k/fpe/fpu_hyperb.c:1.8
--- src/sys/arch/m68k/fpe/fpu_hyperb.c:1.7	Sat Mar 23 12:06:24 2013
+++ src/sys/arch/m68k/fpe/fpu_hyperb.c	Thu Apr 11 13:27:11 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: fpu_hyperb.c,v 1.7 2013/03/23 12:06:24 isaki Exp $	*/
+/*	$NetBSD: fpu_hyperb.c,v 1.8 2013/04/11 13:27:11 isaki Exp $	*/
 
 /*
  * Copyright (c) 1995  Ken Nakata
@@ -57,7 +57,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: fpu_hyperb.c,v 1.7 2013/03/23 12:06:24 isaki Exp $);
+__KERNEL_RCSID(0, $NetBSD: fpu_hyperb.c,v 1.8 2013/04/11 13:27:11 isaki Exp $);
 
 #include fpu_emulate.h
 
@@ -89,7 +89,7 @@ fpu_cosh(struct fpemu *fe)
 		return fe-fe_f2;
 	}
 
-	fpu_const(s0, 0x32);	/* 1.0 */
+	fpu_const(s0, FPU_CONST_1);
 	r = fpu_sincos_taylor(fe, s0, 1, hyperb);
 	CPYFPN(fe-fe_f2, r);
 
@@ -128,7 +128,7 @@ fpu_tanh(struct fpemu *fe)
 
 	if (ISINF(fe-fe_f2)) {
 		sign = fe-fe_f2.fp_sign;
-		fpu_const(fe-fe_f2, 0x32);
+		fpu_const(fe-fe_f2, FPU_CONST_1);
 		fe-fe_f2.fp_sign = sign;
 		return fe-fe_f2;
 	}

Index: src/sys/arch/m68k/fpe/fpu_log.c
diff -u src/sys/arch/m68k/fpe/fpu_log.c:1.15 src/sys/arch/m68k/fpe/fpu_log.c:1.16
--- src/sys/arch/m68k/fpe/fpu_log.c:1.15	Tue Mar 26 11:30:21 2013
+++ src/sys/arch/m68k/fpe/fpu_log.c	Thu Apr 11 13:27:11 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: fpu_log.c,v 1.15 2013/03/26 11:30:21 isaki Exp $	*/
+/*	$NetBSD: fpu_log.c,v 1.16 2013/04/11 13:27:11 isaki Exp $	*/
 
 /*
  * Copyright (c) 1995  Ken Nakata
@@ -32,7 +32,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: fpu_log.c,v 1.15 2013/03/26 11:30:21 isaki Exp $);
+__KERNEL_RCSID(0, $NetBSD: fpu_log.c,v 1.16 2013/04/11 13:27:11 isaki Exp $);
 
 #include sys/types.h
 #include sys/systm.h
@@ -210,13 +210,13 @@ __fpu_logn(struct fpemu *fe)
 		printf(__fpu_logn: log near 1\n);
 #endif
 
-		fpu_const(fe-fe_f1, 0x32);
+		fpu_const(fe-fe_f1, FPU_CONST_1);
 		/* X+1 */
 		d = fpu_add(fe);
 		CPYFPN(V, d);
 
 		CPYFPN(fe-fe_f1, X);
-		fpu_const(fe-fe_f2, 0x32); /* 1.0 */
+		fpu_const(fe-fe_f2, FPU_CONST_1);
 		fe-fe_f2.fp_sign = 1; /* -1.0 */
 		/* X-1 */
 		d = fpu_add(fe);
@@ -352,7 +352,7 @@ __fpu_logn(struct fpemu *fe)
 		/* KLOG2 = K * ln(2) */
 		/* fe_f1 == (fpn)k */
 		fpu_explode(fe, fe-fe_f1, FTYPE_LNG, k);
-		(void)fpu_const(fe-fe_f2, 0x30 /* ln(2) */);
+		(void)fpu_const(fe-fe_f2, FPU_CONST_LN_2);
 #if FPE_DEBUG
 		printf(__fpu_logn: fp(k)=(%d,%08x,%08x...)\n,
 		fe-fe_f1.fp_exp,
@@ -491,7 +491,7 @@ fpu_log10(struct fpemu *fe)
 			fp = __fpu_logn(fe);
 			if (fp != fe-fe_f1)
 CPYFPN(fe-fe_f1, fp);
-			(void)fpu_const(fe-fe_f2, 0x31 /* ln(10) */);
+			(void)fpu_const(fe-fe_f2, FPU_CONST_LN_10);
 			fp = fpu_div(fe);
 		} /* else if fp == +Inf, return +Inf */
 	} else if (fp-fp_class == FPC_ZERO) {
@@ -535,7 +535,7 @@ fpu_log2(struct fpemu *fe)
 fp = __fpu_logn(fe);
 if (fp != fe-fe_f1)
 	CPYFPN(fe-fe_f1, fp);
-(void)fpu_const(fe-fe_f2, 0x30 /* ln(2) */);
+(void)fpu_const(fe-fe_f2, FPU_CONST_LN_2);
 fp = fpu_div(fe);
 			}
 		} /* else if fp == +Inf, return +Inf */
@@ -594,7 +594,7 @@ fpu_lognp1(struct fpemu *fe)
 	struct fpn *fp;
 
 	/* build a 1.0 */
-	fp = fpu_const(fe-fe_f1, 0x32); /* get 1.0 */
+	fp = fpu_const(fe-fe_f1, FPU_CONST_1);
 	/* fp = 1.0 + f2 */
 	fp = fpu_add(fe);
 

Index: src/sys/arch/m68k/fpe/fpu_trig.c
diff -u 

CVS commit: src/distrib/sets/lists/debug

2013-04-11 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Apr 11 13:55:40 UTC 2013

Modified Files:
src/distrib/sets/lists/debug: shl.mi

Log Message:
links to debug libraries


To generate a diff of this commit:
cvs rdiff -u -r1.20 -r1.21 src/distrib/sets/lists/debug/shl.mi

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/debug/shl.mi
diff -u src/distrib/sets/lists/debug/shl.mi:1.20 src/distrib/sets/lists/debug/shl.mi:1.21
--- src/distrib/sets/lists/debug/shl.mi:1.20	Mon Apr  8 14:46:01 2013
+++ src/distrib/sets/lists/debug/shl.mi	Thu Apr 11 09:55:39 2013
@@ -1,4 +1,12 @@
-# $NetBSD: shl.mi,v 1.20 2013/04/08 18:46:01 spz Exp $
+# $NetBSD: shl.mi,v 1.21 2013/04/11 13:55:39 christos Exp $
+./usr/libdata/debug/lib/libc.so.12.185.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/libedit.so.3.1.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/libevent.so.3.2.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/libkvm.so.6.0.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/libpcap.so.5.0.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/librumpclient.so.0.0.debug	comp-sys-debug	debug
+./usr/libdata/debug/lib/libterminfo.so.1.0.debug	comp-sys-debug	debug
+./usr/libdata/debug/lib/libutil.so.7.21.debug		comp-sys-debug	debug
 ./usr/libdata/debug/lib/npf/ext_log.so.0.0.debug	comp-sys-debug	debug,npf
 ./usr/libdata/debug/lib/npf/ext_normalize.so.0.0.debug	comp-sys-debug	debug,npf
 ./usr/libdata/debug/lib/npf/ext_rndblock.so.0.0.debug	comp-sys-debug	debug,npf



CVS commit: src/distrib/sets/lists/debug

2013-04-11 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Thu Apr 11 14:14:35 UTC 2013

Modified Files:
src/distrib/sets/lists/debug: shl.mi

Log Message:
More links to debug libraries


To generate a diff of this commit:
cvs rdiff -u -r1.21 -r1.22 src/distrib/sets/lists/debug/shl.mi

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/debug/shl.mi
diff -u src/distrib/sets/lists/debug/shl.mi:1.21 src/distrib/sets/lists/debug/shl.mi:1.22
--- src/distrib/sets/lists/debug/shl.mi:1.21	Thu Apr 11 13:55:39 2013
+++ src/distrib/sets/lists/debug/shl.mi	Thu Apr 11 14:14:35 2013
@@ -1,12 +1,25 @@
-# $NetBSD: shl.mi,v 1.21 2013/04/11 13:55:39 christos Exp $
+# $NetBSD: shl.mi,v 1.22 2013/04/11 14:14:35 skrll Exp $
 ./usr/libdata/debug/lib/libc.so.12.185.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/libcrypt.so.1.0.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/libcrypto.so.8.1.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/libdevmapper.so.1.0.debug	comp-sys-debug	debug
 ./usr/libdata/debug/lib/libedit.so.3.1.debug		comp-sys-debug	debug
 ./usr/libdata/debug/lib/libevent.so.3.2.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/libgcc_s.so.1.0.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/libipsec.so.3.0.debug		comp-sys-debug	debug
 ./usr/libdata/debug/lib/libkvm.so.6.0.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/liblzf.so.1.0.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/liblzma.so.1.1.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/libm.so.0.10.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/libnpf.so.0.0.debug		comp-sys-debug	debug
 ./usr/libdata/debug/lib/libpcap.so.5.0.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/libppath.so.0.0.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/libprop.so.1.1.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/libradius.so.4.0.debug		comp-sys-debug	debug
 ./usr/libdata/debug/lib/librumpclient.so.0.0.debug	comp-sys-debug	debug
 ./usr/libdata/debug/lib/libterminfo.so.1.0.debug	comp-sys-debug	debug
 ./usr/libdata/debug/lib/libutil.so.7.21.debug		comp-sys-debug	debug
+./usr/libdata/debug/lib/libz.so.1.0.debug		comp-sys-debug	debug
 ./usr/libdata/debug/lib/npf/ext_log.so.0.0.debug	comp-sys-debug	debug,npf
 ./usr/libdata/debug/lib/npf/ext_normalize.so.0.0.debug	comp-sys-debug	debug,npf
 ./usr/libdata/debug/lib/npf/ext_rndblock.so.0.0.debug	comp-sys-debug	debug,npf



CVS commit: src/external/bsd/libevent/man

2013-04-11 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Apr 11 16:05:58 UTC 2013

Update of /cvsroot/src/external/bsd/libevent/man
In directory ivanova.netbsd.org:/tmp/cvs-serv25203

Log Message:
import doxygen generated pages for libevent.
mandoc renders them butt-ugly.

Status:

Vendor Tag: LIBEVENT
Release Tags:   libevent-2-0-21-stable

N src/external/bsd/libevent/man/buffer.h.3
N src/external/bsd/libevent/man/buffer_compat.h.3
N src/external/bsd/libevent/man/dns.h.3
N src/external/bsd/libevent/man/bufferevent_ssl.h.3
N src/external/bsd/libevent/man/dns_compat.h.3
N src/external/bsd/libevent/man/event.h.3
N src/external/bsd/libevent/man/rpc.h.3
N src/external/bsd/libevent/man/event_compat.h.3
N src/external/bsd/libevent/man/http.h.3
N src/external/bsd/libevent/man/http_compat.h.3
N src/external/bsd/libevent/man/rpc_compat.h.3
N src/external/bsd/libevent/man/tag.h.3
N src/external/bsd/libevent/man/tag_compat.h.3
N src/external/bsd/libevent/man/thread.h.3
N src/external/bsd/libevent/man/util.h.3
N src/external/bsd/libevent/man/deprecated.3
N src/external/bsd/libevent/man/bufferevent.3
N src/external/bsd/libevent/man/evbuffer_cb_info.3
N src/external/bsd/libevent/man/evbuffer_iovec.3
N src/external/bsd/libevent/man/evbuffer_ptr.3
N src/external/bsd/libevent/man/event_base.3
N src/external/bsd/libevent/man/event_config.3
N src/external/bsd/libevent/man/evthread_condition_callbacks.3
N src/external/bsd/libevent/man/evthread_lock_callbacks.3
N src/external/bsd/libevent/man/evutil_addrinfo.3

No conflicts created by this import



CVS commit: src/external/bsd/libevent/man

2013-04-11 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Apr 11 16:06:48 UTC 2013

Added Files:
src/external/bsd/libevent/man: Makefile fixman

Log Message:
Add build glue


To generate a diff of this commit:
cvs rdiff -u -r0 -r1.1 src/external/bsd/libevent/man/Makefile \
src/external/bsd/libevent/man/fixman

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Added files:

Index: src/external/bsd/libevent/man/Makefile
diff -u /dev/null src/external/bsd/libevent/man/Makefile:1.1
--- /dev/null	Thu Apr 11 12:06:48 2013
+++ src/external/bsd/libevent/man/Makefile	Thu Apr 11 12:06:47 2013
@@ -0,0 +1,54 @@
+# $NetBSD: Makefile,v 1.1 2013/04/11 16:06:47 christos Exp $
+
+# Try to undo the doxygen lossage in the man pages.
+
+HSRCS1= \
+buffer.h.3 \
+buffer_compat.h.3 \
+dns.h.3 \
+dns_compat.h.3 \
+http.h.3 \
+http_compat.h.3 \
+rpc.h.3 \
+rpc_compat.h.3 \
+tag.h.3 \
+tag_compat.h.3 \
+thread.h.3 \
+util.h.3
+
+HMAN1=${HSRCS1:S/^/ev/g:S/.h.3/.3/g}
+
+.for i in ${HSRCS1}
+ev${i:S/.h.3/.3/g}: $i
+	${.CURDIR}/fixman ${TOOL_SED} ${.ALLSRC} ${.TARGET}
+.endfor
+
+HSRCS2= \
+bufferevent_ssl.h.3 \
+event.h.3 \
+event_compat.h.3
+
+.for i in ${HSRCS2}
+${i:S/.h.3/.3/g}: $i
+	${.CURDIR}/fixman ${TOOL_SED} ${.ALLSRC} ${.TARGET}
+.endfor
+
+HMAN2=${HSRCS2:S/.h.3/.3/g}
+
+MAN+= \
+bufferevent.3 \
+deprecated.3 \
+evbuffer_cb_info.3 \
+evbuffer_iovec.3 \
+evbuffer_ptr.3 \
+event_base.3 \
+event_config.3 \
+evthread_condition_callbacks.3 \
+evthread_lock_callbacks.3 \
+evutil_addrinfo.3
+
+MAN+= ${HMAN1} ${HMAN2}
+
+CLEANFILES+=${HMAN1} ${HMAN2}
+
+.include bsd.man.mk
Index: src/external/bsd/libevent/man/fixman
diff -u /dev/null src/external/bsd/libevent/man/fixman:1.1
--- /dev/null	Thu Apr 11 12:06:48 2013
+++ src/external/bsd/libevent/man/fixman	Thu Apr 11 12:06:47 2013
@@ -0,0 +1,18 @@
+#!/bin/sh
+SED=$1
+in=$2
+out=$3
+name=${in##*/}
+
+case ${name} in
+ev*|bufferev*)	ev=;;
+*)		ev=ev;;
+esac
+
+${SED} \
+	-e s@event2/${name%.3}@${ev}${name%.h.3}@g \
+	-e '/^\.SH SYNOPSIS/,/^\.PP/ {
+	/^.PP/a\
+\\fC#include event2/'${name%.h.3}'\\\.h\\fP\
+.br
+}'  ${in}  ${out}



CVS commit: src/external/bsd/libevent/dist

2013-04-11 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Apr 11 16:43:36 UTC 2013

Update of /cvsroot/src/external/bsd/libevent/dist
In directory ivanova.netbsd.org:/tmp/cvs-serv12904

Log Message:
import libevent 2.x

Status:

Vendor Tag: LIBEVENT
Release Tags:   libevent-2-0-21-stable

N src/external/bsd/libevent/dist/Makefile.in
N src/external/bsd/libevent/dist/evmap-internal.h
N src/external/bsd/libevent/dist/event_iocp.c
N src/external/bsd/libevent/dist/win32select.c
N src/external/bsd/libevent/dist/configure.in
N src/external/bsd/libevent/dist/epoll.c
U src/external/bsd/libevent/dist/evrpc-internal.h
N src/external/bsd/libevent/dist/autogen.sh
U src/external/bsd/libevent/dist/event.h
N src/external/bsd/libevent/dist/evutil_rand.c
U src/external/bsd/libevent/dist/event.c
N src/external/bsd/libevent/dist/libevent_openssl.pc.in
N src/external/bsd/libevent/dist/Makefile.nmake
N src/external/bsd/libevent/dist/evmap.c
N src/external/bsd/libevent/dist/make-event-config.sed
N src/external/bsd/libevent/dist/ratelim-internal.h
N src/external/bsd/libevent/dist/log-internal.h
N src/external/bsd/libevent/dist/util-internal.h
U src/external/bsd/libevent/dist/evdns.c
N src/external/bsd/libevent/dist/evthread-internal.h
N src/external/bsd/libevent/dist/defer-internal.h
N src/external/bsd/libevent/dist/libevent.pc.in
N src/external/bsd/libevent/dist/strlcpy.c
N src/external/bsd/libevent/dist/arc4random.c
U src/external/bsd/libevent/dist/event_tagging.c
U src/external/bsd/libevent/dist/select.c
N src/external/bsd/libevent/dist/configure
U src/external/bsd/libevent/dist/kqueue.c
N src/external/bsd/libevent/dist/depcomp
N src/external/bsd/libevent/dist/missing
U src/external/bsd/libevent/dist/http-internal.h
N src/external/bsd/libevent/dist/devpoll.c
N src/external/bsd/libevent/dist/bufferevent_ratelim.c
N src/external/bsd/libevent/dist/bufferevent_sock.c
N src/external/bsd/libevent/dist/whatsnew-2.0.txt
N src/external/bsd/libevent/dist/config.sub
N src/external/bsd/libevent/dist/buffer_iocp.c
N src/external/bsd/libevent/dist/evthread_pthread.c
U src/external/bsd/libevent/dist/evutil.c
N src/external/bsd/libevent/dist/evthread.c
U src/external/bsd/libevent/dist/signal.c
N src/external/bsd/libevent/dist/bufferevent.c
N src/external/bsd/libevent/dist/bufferevent_openssl.c
U src/external/bsd/libevent/dist/strlcpy-internal.h
U src/external/bsd/libevent/dist/README
N src/external/bsd/libevent/dist/mm-internal.h
U src/external/bsd/libevent/dist/event-internal.h
N src/external/bsd/libevent/dist/install-sh
N src/external/bsd/libevent/dist/evport.c
N src/external/bsd/libevent/dist/config.guess
N src/external/bsd/libevent/dist/Doxyfile
N src/external/bsd/libevent/dist/ht-internal.h
U src/external/bsd/libevent/dist/log.c
N src/external/bsd/libevent/dist/epoll_sub.c
N src/external/bsd/libevent/dist/listener.c
U src/external/bsd/libevent/dist/evrpc.c
N src/external/bsd/libevent/dist/bufferevent_filter.c
N src/external/bsd/libevent/dist/evsignal-internal.h
N src/external/bsd/libevent/dist/evthread_win32.c
N src/external/bsd/libevent/dist/bufferevent_pair.c
U src/external/bsd/libevent/dist/poll.c
N src/external/bsd/libevent/dist/config.h.in
N src/external/bsd/libevent/dist/evbuffer-internal.h
N src/external/bsd/libevent/dist/compile
N src/external/bsd/libevent/dist/ltmain.sh
U src/external/bsd/libevent/dist/buffer.c
N src/external/bsd/libevent/dist/bufferevent_async.c
U src/external/bsd/libevent/dist/ChangeLog
U src/external/bsd/libevent/dist/evdns.h
N src/external/bsd/libevent/dist/LICENSE
N src/external/bsd/libevent/dist/ipv6-internal.h
U src/external/bsd/libevent/dist/http.c
N src/external/bsd/libevent/dist/libevent_pthreads.pc.in
N src/external/bsd/libevent/dist/aclocal.m4
U src/external/bsd/libevent/dist/evutil.h
N src/external/bsd/libevent/dist/minheap-internal.h
U src/external/bsd/libevent/dist/evrpc.h
N src/external/bsd/libevent/dist/bufferevent-internal.h
N src/external/bsd/libevent/dist/iocp-internal.h
U src/external/bsd/libevent/dist/evhttp.h
N src/external/bsd/libevent/dist/event_rpcgen.py
N src/external/bsd/libevent/dist/changelist-internal.h
N src/external/bsd/libevent/dist/Makefile.am
N src/external/bsd/libevent/dist/m4/acx_pthread.m4
N src/external/bsd/libevent/dist/m4/ltsugar.m4
N src/external/bsd/libevent/dist/m4/lt~obsolete.m4
N src/external/bsd/libevent/dist/m4/ltoptions.m4
N src/external/bsd/libevent/dist/m4/ltversion.m4
N src/external/bsd/libevent/dist/m4/libtool.m4
N src/external/bsd/libevent/dist/sample/signal-test.c
N src/external/bsd/libevent/dist/sample/event-test.c
N src/external/bsd/libevent/dist/sample/dns-example.c
N src/external/bsd/libevent/dist/sample/Makefile.in
N src/external/bsd/libevent/dist/sample/http-server.c
N src/external/bsd/libevent/dist/sample/time-test.c
N src/external/bsd/libevent/dist/sample/hello-world.c
N src/external/bsd/libevent/dist/sample/le-proxy.c
N src/external/bsd/libevent/dist/sample/Makefile.am
C src/external/bsd/libevent/dist/test/regress_dns.c

CVS commit: src/external/bsd/libevent/include

2013-04-11 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Apr 11 16:55:51 UTC 2013

Modified Files:
src/external/bsd/libevent/include: Makefile
Added Files:
src/external/bsd/libevent/include/event2: event-config.h
Removed Files:
src/external/bsd/libevent/include: config.h

Log Message:
Event2 build gluons


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/external/bsd/libevent/include/Makefile
cvs rdiff -u -r1.1 -r0 src/external/bsd/libevent/include/config.h
cvs rdiff -u -r0 -r1.1 \
src/external/bsd/libevent/include/event2/event-config.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/libevent/include/Makefile
diff -u src/external/bsd/libevent/include/Makefile:1.1 src/external/bsd/libevent/include/Makefile:1.2
--- src/external/bsd/libevent/include/Makefile:1.1	Mon Nov  2 05:03:56 2009
+++ src/external/bsd/libevent/include/Makefile	Thu Apr 11 12:55:51 2013
@@ -1,8 +1,38 @@
-#	$NetBSD: Makefile,v 1.1 2009/11/02 10:03:56 plunky Exp $
+#	$NetBSD: Makefile,v 1.2 2013/04/11 16:55:51 christos Exp $
 
 .include bsd.init.mk
 
-INCS=		evdns.h event.h evhttp.h evrpc.h evutil.h event-config.h
-INCSDIR=	/usr/include
+INCSDIR=/usr/include
+INCS= \
+evdns.h \
+event.h \
+evhttp.h \
+evrpc.h \
+evutil.h \
+event2/buffer.h \
+event2/buffer_compat.h \
+event2/bufferevent.h \
+event2/bufferevent_compat.h \
+event2/bufferevent_ssl.h \
+event2/bufferevent_struct.h \
+event2/dns.h \
+event2/dns_compat.h \
+event2/dns_struct.h \
+event2/event-config.h \
+event2/event.h \
+event2/event_compat.h \
+event2/event_struct.h \
+event2/http.h \
+event2/http_compat.h \
+event2/http_struct.h \
+event2/keyvalq_struct.h \
+event2/listener.h \
+event2/rpc.h \
+event2/rpc_compat.h \
+event2/rpc_struct.h \
+event2/tag.h \
+event2/tag_compat.h \
+event2/thread.h \
+event2/util.h
 
 .include bsd.prog.mk

Added files:

Index: src/external/bsd/libevent/include/event2/event-config.h
diff -u /dev/null src/external/bsd/libevent/include/event2/event-config.h:1.1
--- /dev/null	Thu Apr 11 12:55:51 2013
+++ src/external/bsd/libevent/include/event2/event-config.h	Thu Apr 11 12:55:51 2013
@@ -0,0 +1,475 @@
+/* event2/event-config.h
+ *
+ * This file was generated by autoconf when libevent was built, and post-
+ * processed by Libevent so that its macros would have a uniform prefix.
+ *
+ * DO NOT EDIT THIS FILE.
+ *
+ * Do not rely on macros in this file existing in later versions.
+ */
+
+#ifndef _EVENT2_EVENT_CONFIG_H_
+#define _EVENT2_EVENT_CONFIG_H_
+
+/* config.h.  Generated from config.h.in by configure.  */
+/* config.h.in.  Generated from configure.in by autoheader.  */
+
+/* Define if libevent should build without support for a debug mode */
+/* #undef _EVENT_DISABLE_DEBUG_MODE */
+
+/* Define if libevent should not allow replacing the mm functions */
+/* #undef _EVENT_DISABLE_MM_REPLACEMENT */
+
+/* Define if libevent should not be compiled with thread support */
+/* #undef _EVENT_DISABLE_THREAD_SUPPORT */
+
+/* Define to 1 if you have the `arc4random' function. */
+#define _EVENT_HAVE_ARC4RANDOM 1
+
+/* Define to 1 if you have the `arc4random_buf' function. */
+#define _EVENT_HAVE_ARC4RANDOM_BUF 1
+
+/* Define to 1 if you have the arpa/inet.h header file. */
+#define _EVENT_HAVE_ARPA_INET_H 1
+
+/* Define to 1 if you have the `clock_gettime' function. */
+#define _EVENT_HAVE_CLOCK_GETTIME 1
+
+/* Define to 1 if you have the declaration of `CTL_KERN', and to 0 if you
+   don't. */
+#define _EVENT_HAVE_DECL_CTL_KERN 1
+
+/* Define to 1 if you have the declaration of `KERN_ARND', and to 0 if you
+   don't. */
+#define _EVENT_HAVE_DECL_KERN_ARND 1
+
+/* Define to 1 if you have the declaration of `KERN_RANDOM', and to 0 if you
+   don't. */
+#define _EVENT_HAVE_DECL_KERN_RANDOM 0
+
+/* Define to 1 if you have the declaration of `RANDOM_UUID', and to 0 if you
+   don't. */
+#define _EVENT_HAVE_DECL_RANDOM_UUID 0
+
+/* Define if /dev/poll is available */
+/* #undef _EVENT_HAVE_DEVPOLL */
+
+/* Define to 1 if you have the dlfcn.h header file. */
+#define _EVENT_HAVE_DLFCN_H 1
+
+/* Define if your system supports the epoll system calls */
+/* #undef _EVENT_HAVE_EPOLL */
+
+/* Define to 1 if you have the `epoll_ctl' function. */
+/* #undef _EVENT_HAVE_EPOLL_CTL */
+
+/* Define to 1 if you have the `eventfd' function. */
+/* #undef _EVENT_HAVE_EVENTFD */
+
+/* Define if your system supports event ports */
+/* #undef _EVENT_HAVE_EVENT_PORTS */
+
+/* Define to 1 if you have the `fcntl' function. */
+#define _EVENT_HAVE_FCNTL 1
+
+/* Define to 1 if you have the fcntl.h header file. */
+#define _EVENT_HAVE_FCNTL_H 1
+
+/* Define to 1 if the system has the type `fd_mask'. */
+#define _EVENT_HAVE_FD_MASK 1
+
+/* Do we have getaddrinfo()? */
+#define _EVENT_HAVE_GETADDRINFO 1
+
+/* Define to 1 if you have the `getegid' function. */
+#define _EVENT_HAVE_GETEGID 1
+
+/* Define to 1 if you have the `geteuid' 

CVS commit: src/external/bsd/libevent

2013-04-11 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Apr 11 16:56:11 UTC 2013

Added Files:
src/external/bsd/libevent: libevent2netbsd

Log Message:
import script


To generate a diff of this commit:
cvs rdiff -u -r0 -r1.1 src/external/bsd/libevent/libevent2netbsd

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Added files:

Index: src/external/bsd/libevent/libevent2netbsd
diff -u /dev/null src/external/bsd/libevent/libevent2netbsd:1.1
--- /dev/null	Thu Apr 11 12:56:11 2013
+++ src/external/bsd/libevent/libevent2netbsd	Thu Apr 11 12:56:11 2013
@@ -0,0 +1,109 @@
+#!/bin/sh
+# $NetBSD: libevent2netbsd,v 1.1 2013/04/11 16:56:11 christos Exp $
+
+# Extract the new tarball and rename the libevent-X.Y.Z directory
+# to dist.  Run this script and check for additional files and
+# directories to prune, only relevant content is included.
+#
+# lib/ is built as SUBDIR from lib/Makefile, and
+# the regression tests are used from tests/lib/libevent
+#
+# Use the following template to import
+#  cvs import src/external/bsd/libevent/dist LIBEVENT libevent-X-Y-Z-stable
+#
+# don't forget to bump the shlib version in Makefile.inc and
+# commit the include/ files
+# XXX: Automate the man page generation
+
+if [ -z $1 ]
+then
+echo Usage $0 dir 12
+exit 1
+fi
+
+case $1 in
+/*)
+	d=$1;;
+*)
+	d=$(pwd)/$1;;
+esac
+
+if [ -f $d/configure ]; then
+	mkdir -p tmp
+	cd tmp
+	$d/configure
+	make include/event2/event-config.h
+	sed -e '
+/_EVENT_SIZEOF_SIZE_T/ {
+	a\
+#ifdef _LP64\
+#define _EVENT_SIZEOF_SIZE_T 8\
+#else\
+#define _EVENT_SIZEOF_SIZE_T 4\
+#endif
+	d
+}
+/_EVENT_SIZEOF_LONG/ {
+	a\
+#ifdef _LP64\
+#define _EVENT_SIZEOF_LONG 8\
+#else\
+#define _EVENT_SIZEOF_LONG 4\
+#endif
+	d
+}
+/_EVENT_SIZEOF_PTHREAD_T/ {
+	a\
+#ifdef _LP64\
+#define _EVENT_SIZEOF_PTHREAD_T 8\
+#else\
+#define _EVENT_SIZEOF_PTHREAD_T 4\
+#endif
+	d
+}
+/_EVENT_SIZEOF_VOID_P/ {
+	a\
+#ifdef _LP64\
+#define _EVENT_SIZEOF_VOID_P 8\
+#else\
+#define _EVENT_SIZEOF_VOID_P 4\
+#endif
+	d
+}'  include/event2/event-config.h  ../include/event2/event-config.h
+	cd ..
+	rm -Rf tmp
+fi
+
+echo Removing RCS tags...
+cleantags $d
+
+echo Adding RCS tags ..
+for f in $(grep -RL '\$NetBSD.*\$' $d include | grep -v CVS); do
+	case $f in
+	*.c)
+		sed -e '1i\
+/*	\$NetBSD\$	*/
+' -e '/#include event2\/event-config.h/ {
+a\
+#include sys/cdefs.h\
+__RCSID(\$NetBSD\$);
+}'  $f  tmp$$  mv tmp$$ $f
+		;;
+	*.h)
+		cat - ${f}  ${f}_tmp - EOF
+			/*	\$NetBSD\$	*/
+		EOF
+		mv ${f}_tmp ${f}
+		;;
+	*.[0-9])
+		cat - ${f}  ${f}_tmp - EOF
+			.\	\$NetBSD\$
+			.\
+		EOF
+		mv ${f}_tmp ${f}
+		;;
+	*)
+		echo No RCS tag added to ${f}
+		;;
+	esac
+done



CVS commit: src/external/bsd/libevent

2013-04-11 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Apr 11 16:59:17 UTC 2013

Modified Files:
src/external/bsd/libevent: Makefile Makefile.inc
src/external/bsd/libevent/lib: Makefile
Added Files:
src/external/bsd/libevent/lib: Makefile.inc
src/external/bsd/libevent/lib/libevent: Makefile
src/external/bsd/libevent/lib/libevent_openssl: Makefile
src/external/bsd/libevent/lib/libevent_pthreads: Makefile
Removed Files:
src/external/bsd/libevent: prepare-import.sh
src/external/bsd/libevent/lib: shlib_version

Log Message:
the rest of the build glue.


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/external/bsd/libevent/Makefile \
src/external/bsd/libevent/Makefile.inc
cvs rdiff -u -r1.2 -r0 src/external/bsd/libevent/prepare-import.sh
cvs rdiff -u -r1.1 -r1.2 src/external/bsd/libevent/lib/Makefile
cvs rdiff -u -r0 -r1.1 src/external/bsd/libevent/lib/Makefile.inc
cvs rdiff -u -r1.1 -r0 src/external/bsd/libevent/lib/shlib_version
cvs rdiff -u -r0 -r1.1 src/external/bsd/libevent/lib/libevent/Makefile
cvs rdiff -u -r0 -r1.1 \
src/external/bsd/libevent/lib/libevent_openssl/Makefile
cvs rdiff -u -r0 -r1.1 \
src/external/bsd/libevent/lib/libevent_pthreads/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/libevent/Makefile
diff -u src/external/bsd/libevent/Makefile:1.1 src/external/bsd/libevent/Makefile:1.2
--- src/external/bsd/libevent/Makefile:1.1	Mon Nov  2 05:03:56 2009
+++ src/external/bsd/libevent/Makefile	Thu Apr 11 12:59:16 2013
@@ -1,5 +1,5 @@
-#	$NetBSD: Makefile,v 1.1 2009/11/02 10:03:56 plunky Exp $
+# $NetBSD: Makefile,v 1.2 2013/04/11 16:59:16 christos Exp $
 
-SUBDIR=		include lib
+SUBDIR = include lib man
 
 .include bsd.subdir.mk
Index: src/external/bsd/libevent/Makefile.inc
diff -u src/external/bsd/libevent/Makefile.inc:1.1 src/external/bsd/libevent/Makefile.inc:1.2
--- src/external/bsd/libevent/Makefile.inc:1.1	Mon Nov  2 05:03:56 2009
+++ src/external/bsd/libevent/Makefile.inc	Thu Apr 11 12:59:16 2013
@@ -1,12 +1,17 @@
-# $NetBSD: Makefile.inc,v 1.1 2009/11/02 10:03:56 plunky Exp $
+# $NetBSD: Makefile.inc,v 1.2 2013/04/11 16:59:16 christos Exp $
 
 .include bsd.own.mk
 
 LIBEVENT_DIR=	${NETBSDSRCDIR}/external/bsd/libevent
+LIBEVENT_DIST=	${LIBEVENT_DIR}/dist
 
 CPPFLAGS+=	-DHAVE_CONFIG_H
-CPPFLAGS+=	-I${LIBEVENT_DIR}/dist -I${LIBEVENT_DIR}/include
+CPPFLAGS+=	-I${LIBEVENT_DIST} -I${LIBEVENT_DIR}/include
+CPPFLAGS+=	-I${LIBEVENT_DIST}/include
+
+SHLIB_MAJOR=	4
+SHLIB_MINOR=	0
 
 WARNS?=		4
 
-.PATH:		${LIBEVENT_DIR}/dist
+.PATH:		${LIBEVENT_DIST} ${LIBEVENT_DIST}/include

Index: src/external/bsd/libevent/lib/Makefile
diff -u src/external/bsd/libevent/lib/Makefile:1.1 src/external/bsd/libevent/lib/Makefile:1.2
--- src/external/bsd/libevent/lib/Makefile:1.1	Mon Nov  2 05:03:56 2009
+++ src/external/bsd/libevent/lib/Makefile	Thu Apr 11 12:59:16 2013
@@ -1,98 +1,10 @@
-#	$NetBSD: Makefile,v 1.1 2009/11/02 10:03:56 plunky Exp $
+#	$NetBSD: Makefile,v 1.2 2013/04/11 16:59:16 christos Exp $
+.include bsd.own.mk
 
-.include bsd.init.mk
+SUBDIR=	 libevent
+.if ${MKCRYPTO} != no
+SUBDIR+=	libevent_openssl
+.endif
+SUBDIR+= libevent_pthreads
 
-LIB=		event
-USE_SHLIBDIR=	yes
-
-SRCS=		buffer.c evbuffer.c evdns.c event.c event_tagging.c \
-		evrpc.c evutil.c http.c kqueue.c log.c poll.c select.c \
-		signal.c
-
-CPPFLAGS+=	-fno-strict-aliasing
-
-CPPFLAGS.evdns.c+=		-Wno-shadow -Wno-cast-qual
-CPPFLAGS.event_tagging.c+=	-Wno-cast-qual
-CPPFLAGS.evrpc.c+=		-Wno-cast-qual
-CPPFLAGS.http.c+=		-Wno-cast-qual -Wno-sign-compare
-CPPFLAGS.kqueue.c+=		-Wno-sign-compare
-CPPFLAGS.select.c+=		-Wno-sign-compare
-
-LINTFLAGS+=	-X 27	# http.c redeclaration of %s
-
-MAN=		evdns.3 event.3
-
-MLINKS+=	event.3 event_init.3
-MLINKS+=	event.3 event_dispatch.3
-MLINKS+=	event.3 event_loop.3
-MLINKS+=	event.3 event_loopexit.3
-MLINKS+=	event.3 event_loopbreak.3
-MLINKS+=	event.3 event_base_dispatch.3
-MLINKS+=	event.3 event_base_free.3
-MLINKS+=	event.3 event_base_loop.3
-MLINKS+=	event.3 event_base_loopexit.3
-MLINKS+=	event.3 event_base_loopbreak.3
-MLINKS+=	event.3 event_base_set.3
-MLINKS+=	event.3 event_set.3
-MLINKS+=	event.3 event_add.3
-MLINKS+=	event.3 event_del.3
-MLINKS+=	event.3 event_once.3
-MLINKS+=	event.3 event_base_once.3
-MLINKS+=	event.3 event_pending.3
-MLINKS+=	event.3 event_initialized.3
-
-MLINKS+=	event.3 evtimer_set.3
-MLINKS+=	event.3 evtimer_add.3
-MLINKS+=	event.3 evtimer_del.3
-MLINKS+=	event.3 evtimer_pending.3
-MLINKS+=	event.3 evtimer_initialized.3
-
-MLINKS+=	event.3 signal_set.3
-MLINKS+=	event.3 signal_add.3
-MLINKS+=	event.3 signal_del.3
-MLINKS+=	event.3 signal_pending.3
-MLINKS+=	event.3 signal_initialized.3
-
-MLINKS+=	event.3 bufferevent_new.3
-MLINKS+=	event.3 bufferevent_free.3
-MLINKS+=	event.3 bufferevent_write.3
-MLINKS+=	event.3 bufferevent_write_buffer.3
-MLINKS+=	

CVS commit: src/tests/lib/libevent

2013-04-11 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Apr 11 17:00:12 UTC 2013

Modified Files:
src/tests/lib/libevent: Makefile

Log Message:
Add new tests sources for event2.


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/tests/lib/libevent/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/tests/lib/libevent/Makefile
diff -u src/tests/lib/libevent/Makefile:1.1 src/tests/lib/libevent/Makefile:1.2
--- src/tests/lib/libevent/Makefile:1.1	Mon Nov  2 05:15:45 2009
+++ src/tests/lib/libevent/Makefile	Thu Apr 11 13:00:12 2013
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.1 2009/11/02 10:15:45 plunky Exp $
+# $NetBSD: Makefile,v 1.2 2013/04/11 17:00:12 christos Exp $
 
 TESTSDIR=	${TESTSBASE}/lib/libevent
 
@@ -7,20 +7,25 @@ TESTS_SH=	t_event
 .include bsd.own.mk
 .include ../../../external/bsd/libevent/Makefile.inc
 
-.PATH:		${LIBEVENT_DIR}/dist/test
+.PATH:		${LIBEVENT_DIST}/test
 
 BINDIR=		${TESTSDIR}
 
 PROG=		h_event
 MAN=		# defined
 SRCS=		regress.c regress.gen.c regress_dns.c regress_http.c \
-		regress_rpc.c
-
-DPADD+=		${LIBEVENT}
-LDADD+=		-levent
-
-CPPFLAGS.regress.c+=		-Wno-cast-qual -Wno-sign-compare -Wno-shadow
-CPPFLAGS.regress_http.c+=	-Wno-cast-qual -Wno-sign-compare -Wno-shadow
-CPPFLAGS.regress_rpc.c+=	-Wno-cast-qual -Wno-shadow
+		regress_rpc.c regress_main.c tinytest.c regress_testutils.c \
+		regress_minheap.c regress_util.c regress_thread.c \
+		regress_buffer.c regress_bufferevent.c regress_listener.c \
+		regress_zlib.c regress_et.c
+
+.if ${MKCRYPTO} == yes
+SRCS+=		regress_ssl.c
+DPADD+=		${LIBEVENT_OPENSSL} ${LIBSSL} ${LIBCRYPTO}
+LDADD+=		-levent_openssl -lssl -lcrypto
+CPPFLAGS+=	-DLIBEVENT_CRYPTO
+.endif
+DPADD+=		${LIBEVENT} ${LIBEVENT_PTHREADS} ${LIBZ} ${LIBPTHREAD}
+LDADD+=		-levent_pthreads -levent -lz -lpthread
 
 .include bsd.test.mk



CVS commit: src/sys/arch/powerpc

2013-04-11 Thread Michael Lorenz
Module Name:src
Committed By:   macallan
Date:   Thu Apr 11 17:13:16 UTC 2013

Modified Files:
src/sys/arch/powerpc/oea: ofwoea_machdep.c pmap.c
src/sys/arch/powerpc/powerpc: trap_subr.S

Log Message:
make PPC_OEA64_BRIDGE mode work
from Phileas Fogg


To generate a diff of this commit:
cvs rdiff -u -r1.31 -r1.32 src/sys/arch/powerpc/oea/ofwoea_machdep.c
cvs rdiff -u -r1.88 -r1.89 src/sys/arch/powerpc/oea/pmap.c
cvs rdiff -u -r1.75 -r1.76 src/sys/arch/powerpc/powerpc/trap_subr.S

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/powerpc/oea/ofwoea_machdep.c
diff -u src/sys/arch/powerpc/oea/ofwoea_machdep.c:1.31 src/sys/arch/powerpc/oea/ofwoea_machdep.c:1.32
--- src/sys/arch/powerpc/oea/ofwoea_machdep.c:1.31	Sat Oct 20 14:42:15 2012
+++ src/sys/arch/powerpc/oea/ofwoea_machdep.c	Thu Apr 11 17:13:15 2013
@@ -1,4 +1,4 @@
-/* $NetBSD: ofwoea_machdep.c,v 1.31 2012/10/20 14:42:15 kiyohara Exp $ */
+/* $NetBSD: ofwoea_machdep.c,v 1.32 2013/04/11 17:13:15 macallan Exp $ */
 
 /*-
  * Copyright (c) 2007 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: ofwoea_machdep.c,v 1.31 2012/10/20 14:42:15 kiyohara Exp $);
+__KERNEL_RCSID(0, $NetBSD: ofwoea_machdep.c,v 1.32 2013/04/11 17:13:15 macallan Exp $);
 
 #include opt_ppcarch.h
 #include opt_compat_netbsd.h
@@ -39,6 +39,8 @@ __KERNEL_RCSID(0, $NetBSD: ofwoea_machd
 #include opt_ipkdb.h
 #include opt_modular.h
 
+#include wsdisplay.h
+
 #include sys/param.h
 #include sys/buf.h
 #include sys/boot_flag.h
@@ -48,6 +50,10 @@ __KERNEL_RCSID(0, $NetBSD: ofwoea_machd
 #include uvm/uvm_extern.h
 
 #include dev/ofw/openfirm.h
+#include dev/wscons/wsconsio.h
+#include dev/wscons/wsdisplayvar.h
+#include dev/rasops/rasops.h
+#include dev/wscons/wsdisplay_vconsvar.h
 #include machine/pmap.h
 #include machine/powerpc.h
 #include machine/trap.h
@@ -55,6 +61,7 @@ __KERNEL_RCSID(0, $NetBSD: ofwoea_machd
 #include machine/autoconf.h
 #include sys/bus.h
 #include powerpc/oea/bat.h
+#include powerpc/oea/ofw_rasconsvar.h
 #include powerpc/oea/cpufeat.h
 #include powerpc/ofw_cons.h
 #include powerpc/spr.h
@@ -230,9 +237,44 @@ ofwoea_initppc(u_int startkernel, u_int 
 #if defined(PPC_OEA64) || defined (PPC_OEA64_BRIDGE)
 #if defined (PMAC_G5)
 	/* Mapin 1st 256MB segment 1:1, also map in mem needed to access OFW*/
-	if (oeacpufeat  OEACPU_64_BRIDGE)
-		pmap_setup_segment0_map(0, 0xff80, 0x3fc0, 0x40,
-		0x0);
+	if (oeacpufeat  OEACPU_64_BRIDGE) {
+		vaddr_t va;
+		paddr_t pa;
+		int i;
+
+		pmap_setup_segment0_map(0, 0x0);
+
+		/* Map OFW code+data */
+
+		for (i = 0; i  ofmaplen / sizeof(struct ofw_translations); i++) {
+			if (ofmap[i].va  0xff80)
+continue;
+
+			for (va = ofmap[i].va, pa = ofmap[i].pa;
+			va  ofmap[i].va + ofmap[i].len;
+			va += PAGE_SIZE, pa += PAGE_SIZE) {
+pmap_enter(pmap_kernel(), va, pa, VM_PROT_ALL,
+VM_PROT_ALL | PMAP_WIRED);
+			}
+		}
+
+#if NWSDISPLAY  0
+		/* Map video frame buffer */
+
+		struct rasops_info *ri = rascons_console_screen.scr_ri;
+
+		if (ri-ri_bits != NULL) {
+			for (va = (vaddr_t) ri-ri_bits;
+			va  round_page((vaddr_t) ri-ri_bits +
+ri-ri_height * ri-ri_stride);
+			va += PAGE_SIZE) {
+pmap_enter(pmap_kernel(), va, va,
+VM_PROT_READ | VM_PROT_WRITE,
+PMAP_NOCACHE | PMAP_WIRED);
+			}
+		}
+#endif
+	}
 #elif defined (MAMBO)
 	/* Mapin 1st 256MB segment 1:1, also map in mem needed to access OFW*/
 	if (oeacpufeat  OEACPU_64_BRIDGE)
@@ -330,10 +372,11 @@ restore_ofmap(struct ofw_translations *m
 
 	pmap_pinit(ofw_pmap);
 
-	ofw_pmap.pm_sr[KERNEL_SR] = KERNEL_SEGMENT;
+	ofw_pmap.pm_sr[0] = KERNELN_SEGMENT(0)|SR_PRKEY;
+	ofw_pmap.pm_sr[KERNEL_SR] = KERNEL_SEGMENT|SR_SUKEY|SR_PRKEY;
 
 #ifdef KERNEL2_SR
-	ofw_pmap.pm_sr[KERNEL2_SR] = KERNEL2_SEGMENT;
+	ofw_pmap.pm_sr[KERNEL2_SR] = KERNEL2_SEGMENT|SR_SUKEY|SR_PRKEY;
 #endif
 
 	for (i = 0; i  n; i++) {
@@ -466,7 +509,7 @@ static void
 find_ranges(int base, rangemap_t *regions, int *cur, int type)
 {
 	int node, i, len, reclen;
-	u_int32_t acells, scells, map[160];
+	u_int32_t parent_acells, acells, scells, map[160];
 	char tmp[32];
 
 	node = base;
@@ -480,12 +523,15 @@ find_ranges(int base, rangemap_t *region
 	len = OF_getprop(node, ranges, map, sizeof(map));
 	if (len == -1)
 		goto rec;
+	if (OF_getprop(OF_parent(node), #address-cells, parent_acells,
+	sizeof(parent_acells)) != sizeof(parent_acells))
+		parent_acells = 1;
 	if (OF_getprop(node, #address-cells, acells,
 	sizeof(acells)) != sizeof(acells))
-		acells = 1;
+		acells = 3;
 	if (OF_getprop(node, #size-cells, scells,
 	sizeof(scells)) != sizeof(scells))
-		scells = 1;
+		scells = 2;
 #ifdef ofppc
 	if (modeldata.ranges_offset == 0)
 		scells -= 1;
@@ -493,7 +539,7 @@ find_ranges(int base, rangemap_t *region
 	if (type == RANGE_TYPE_ISA)
 		reclen = 6;
 	else
-		reclen 

CVS commit: src/external/bsd/libevent/man

2013-04-11 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Apr 11 17:49:13 UTC 2013

Modified Files:
src/external/bsd/libevent/man: Makefile

Log Message:
rename deprecated to evdeprecated.


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/external/bsd/libevent/man/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/libevent/man/Makefile
diff -u src/external/bsd/libevent/man/Makefile:1.1 src/external/bsd/libevent/man/Makefile:1.2
--- src/external/bsd/libevent/man/Makefile:1.1	Thu Apr 11 12:06:47 2013
+++ src/external/bsd/libevent/man/Makefile	Thu Apr 11 13:49:12 2013
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.1 2013/04/11 16:06:47 christos Exp $
+# $NetBSD: Makefile,v 1.2 2013/04/11 17:49:12 christos Exp $
 
 # Try to undo the doxygen lossage in the man pages.
 
@@ -35,9 +35,17 @@ ${i:S/.h.3/.3/g}: $i
 
 HMAN2=${HSRCS2:S/.h.3/.3/g}
 
+SRCS1=deprecated.3
+MAN1=${SRCS1:S/^/ev/g}
+
+.for i in ${SRCS1}
+ev$i: $i
+	${TOOL_SED}  -e 's/deprecated/evdeprecated/g' \
+		-e 's/^deprecated/^evdeprecated/g'  ${.ALLSRC}  ${.TARGET}
+.endfor
+
 MAN+= \
 bufferevent.3 \
-deprecated.3 \
 evbuffer_cb_info.3 \
 evbuffer_iovec.3 \
 evbuffer_ptr.3 \
@@ -47,8 +55,8 @@ evthread_condition_callbacks.3 \
 evthread_lock_callbacks.3 \
 evutil_addrinfo.3
 
-MAN+= ${HMAN1} ${HMAN2}
+MAN+= ${HMAN1} ${HMAN2} ${MAN1}
 
-CLEANFILES+=${HMAN1} ${HMAN2}
+CLEANFILES+=${HMAN1} ${HMAN2} ${MAN1}
 
 .include bsd.man.mk



CVS commit: src/doc

2013-04-11 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Apr 11 17:50:24 UTC 2013

Modified Files:
src/doc: 3RDPARTY CHANGES

Log Message:
new libevent


To generate a diff of this commit:
cvs rdiff -u -r1.1032 -r1.1033 src/doc/3RDPARTY
cvs rdiff -u -r1.1814 -r1.1815 src/doc/CHANGES

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/3RDPARTY
diff -u src/doc/3RDPARTY:1.1032 src/doc/3RDPARTY:1.1033
--- src/doc/3RDPARTY:1.1032	Sun Apr  7 13:19:39 2013
+++ src/doc/3RDPARTY	Thu Apr 11 13:50:23 2013
@@ -1,4 +1,4 @@
-#	$NetBSD: 3RDPARTY,v 1.1032 2013/04/07 17:19:39 christos Exp $
+#	$NetBSD: 3RDPARTY,v 1.1033 2013/04/11 17:50:23 christos Exp $
 #
 # This file contains a list of the software that has been integrated into
 # NetBSD where we are not the primary maintainer.
@@ -654,8 +654,8 @@ The lvm2tools and the libdevmapper are n
 repository. See the lvm2tools Notes for more information.
 
 Package:	libevent
-Version:	1.4.12-stable
-Current Vers:	2.0.2-alpha
+Version:	2.0.21-stable
+Current Vers:	2.0.21-stable
 Maintainer:	Niels Provos pro...@citi.umich.edu
 Archive Site:	http://www.monkey.org/~provos/libevent/
 Home Page:	http://www.monkey.org/~provos/libevent/
@@ -663,6 +663,10 @@ Responsible:	provos
 License:	BSD (3/4-clause)
 Location:	external/bsd/libevent/dist
 Notes:
+- Run the libevent2netbsd script
+- Build the doxygen man pages. Edit the Doxyfile to GENERATE_MAN=yes.
+  man pages are in doxygen/man/man3. Remove the extra man pages that are
+  .so'ing only. Copy the rest to man.
 
 Package:	lvm2tools
 Version:	2.02.56

Index: src/doc/CHANGES
diff -u src/doc/CHANGES:1.1814 src/doc/CHANGES:1.1815
--- src/doc/CHANGES:1.1814	Sat Apr  6 15:33:59 2013
+++ src/doc/CHANGES	Thu Apr 11 13:50:23 2013
@@ -1,4 +1,4 @@
-# LIST OF CHANGES FROM LAST RELEASE:			$Revision: 1.1814 $
+# LIST OF CHANGES FROM LAST RELEASE:			$Revision: 1.1815 $
 #
 #
 # [Note: This file does not mention every change made to the NetBSD source tree.
@@ -225,3 +225,4 @@ Changes from NetBSD 6.0 to NetBSD 7.0:
 	byacc: Import 20130304 [christos 20130405]
 	libpcap: Import 1.3.0 [christos 20130406]
 	tcpdump(8): Import 4.3.0 [christos 20130406]
+	libevent: Upgrade 2.0.21-stable [christos 20130411]



CVS commit: src/etc/mtree

2013-04-11 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Apr 11 17:51:04 UTC 2013

Modified Files:
src/etc/mtree: NetBSD.dist.base

Log Message:
add event2


To generate a diff of this commit:
cvs rdiff -u -r1.117 -r1.118 src/etc/mtree/NetBSD.dist.base

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/etc/mtree/NetBSD.dist.base
diff -u src/etc/mtree/NetBSD.dist.base:1.117 src/etc/mtree/NetBSD.dist.base:1.118
--- src/etc/mtree/NetBSD.dist.base:1.117	Sat Mar 30 14:14:50 2013
+++ src/etc/mtree/NetBSD.dist.base	Thu Apr 11 13:51:04 2013
@@ -1,4 +1,4 @@
-#	$NetBSD: NetBSD.dist.base,v 1.117 2013/03/30 18:14:50 martin Exp $
+#	$NetBSD: NetBSD.dist.base,v 1.118 2013/04/11 17:51:04 christos Exp $
 #	@(#)4.4BSD.dist	8.1 (Berkeley) 6/13/93
 
 # Do not customize this file as it may be overwritten on upgrades.
@@ -125,6 +125,7 @@
 ./usr/include/dev/usb
 ./usr/include/dev/vme
 ./usr/include/dev/wscons
+./usr/include/event2
 ./usr/include/filecorefs
 ./usr/include/fs
 ./usr/include/fs/smbfs



CVS commit: src/sys/arch/powerpc/oea

2013-04-11 Thread Michael Lorenz
Module Name:src
Committed By:   macallan
Date:   Thu Apr 11 18:04:20 UTC 2013

Modified Files:
src/sys/arch/powerpc/oea: ofw_rascons.c

Log Message:
for some reason we can't use the ROM font on G5, so disable it with
options OFWOEA_WSCONS_NO_ROM_FONT
from Phileas Fogg


To generate a diff of this commit:
cvs rdiff -u -r1.8 -r1.9 src/sys/arch/powerpc/oea/ofw_rascons.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/powerpc/oea/ofw_rascons.c
diff -u src/sys/arch/powerpc/oea/ofw_rascons.c:1.8 src/sys/arch/powerpc/oea/ofw_rascons.c:1.9
--- src/sys/arch/powerpc/oea/ofw_rascons.c:1.8	Wed Feb  1 09:54:03 2012
+++ src/sys/arch/powerpc/oea/ofw_rascons.c	Thu Apr 11 18:04:20 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: ofw_rascons.c,v 1.8 2012/02/01 09:54:03 matt Exp $	*/
+/*	$NetBSD: ofw_rascons.c,v 1.9 2013/04/11 18:04:20 macallan Exp $	*/
 
 /*
  * Copyright (c) 1995, 1996 Carnegie-Mellon University.
@@ -28,7 +28,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: ofw_rascons.c,v 1.8 2012/02/01 09:54:03 matt Exp $);
+__KERNEL_RCSID(0, $NetBSD: ofw_rascons.c,v 1.9 2013/04/11 18:04:20 macallan Exp $);
 
 #include wsdisplay.h
 
@@ -98,7 +98,9 @@ rascons_cnattach(void)
 
 	wsfont_init();
 	if (copy_rom_font() == 0) {
+#if !defined(OFWOEA_WSCONS_NO_ROM_FONT)
 		romfont_loaded = 1;
+#endif /* !OFWOEA_WSCONS_NO_ROM_FONT */
 	}
 
 	/* set up rasops */



CVS commit: src/sys/arch/powerpc/pci

2013-04-11 Thread Michael Lorenz
Module Name:src
Committed By:   macallan
Date:   Thu Apr 11 18:14:41 UTC 2013

Modified Files:
src/sys/arch/powerpc/pci: pci_machdep_common.c

Log Message:
temporary kludge for G5 - on mine some devices are configured with interrupt
pin 0 but a valid IRQ line, so don't treat that as an error if PMAC_G5 is set


To generate a diff of this commit:
cvs rdiff -u -r1.16 -r1.17 src/sys/arch/powerpc/pci/pci_machdep_common.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/powerpc/pci/pci_machdep_common.c
diff -u src/sys/arch/powerpc/pci/pci_machdep_common.c:1.16 src/sys/arch/powerpc/pci/pci_machdep_common.c:1.17
--- src/sys/arch/powerpc/pci/pci_machdep_common.c:1.16	Fri Jan 18 06:21:12 2013
+++ src/sys/arch/powerpc/pci/pci_machdep_common.c	Thu Apr 11 18:14:40 2013
@@ -1,4 +1,4 @@
-/* $NetBSD: pci_machdep_common.c,v 1.16 2013/01/18 06:21:12 matt Exp $ */
+/* $NetBSD: pci_machdep_common.c,v 1.17 2013/04/11 18:14:40 macallan Exp $ */
 
 /*-
  * Copyright (c) 2007 The NetBSD Foundation, Inc.
@@ -37,7 +37,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: pci_machdep_common.c,v 1.16 2013/01/18 06:21:12 matt Exp $);
+__KERNEL_RCSID(0, $NetBSD: pci_machdep_common.c,v 1.17 2013/04/11 18:14:40 macallan Exp $);
 
 #define _POWERPC_BUS_DMA_PRIVATE
 
@@ -167,12 +167,17 @@ genppc_pci_intr_map(const struct pci_att
 	printf(%s: pin: %d, line: %d\n, __func__, pin, line);
 #endif
 
+/*
+ * XXX
+ * on my G5 some devices are configured with pin == 0 but a valid IRQ line
+ */
+#ifndef PMAC_G5
 	if (pin == 0) {
 		/* No IRQ used. */
 		aprint_error(pci_intr_map: interrupt pin %d\n, pin);
 		goto bad;
 	}
-
+#endif
 	if (pin  4) {
 		aprint_error(pci_intr_map: bad interrupt pin %d\n, pin);
 		goto bad;



CVS commit: src/sys/arch/powerpc/powerpc

2013-04-11 Thread Michael Lorenz
Module Name:src
Committed By:   macallan
Date:   Thu Apr 11 18:20:33 UTC 2013

Modified Files:
src/sys/arch/powerpc/powerpc: bus_space.c

Log Message:
in memio_map() don't fail without trying to mapiodev() if we don't find a BAT
mapping or don't have BATs
now this works on G5


To generate a diff of this commit:
cvs rdiff -u -r1.34 -r1.35 src/sys/arch/powerpc/powerpc/bus_space.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/powerpc/powerpc/bus_space.c
diff -u src/sys/arch/powerpc/powerpc/bus_space.c:1.34 src/sys/arch/powerpc/powerpc/bus_space.c:1.35
--- src/sys/arch/powerpc/powerpc/bus_space.c:1.34	Wed Jul 18 17:41:59 2012
+++ src/sys/arch/powerpc/powerpc/bus_space.c	Thu Apr 11 18:20:33 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: bus_space.c,v 1.34 2012/07/18 17:41:59 matt Exp $	*/
+/*	$NetBSD: bus_space.c,v 1.35 2013/04/11 18:20:33 macallan Exp $	*/
 
 /*-
  * Copyright (c) 1996, 1997, 1998 The NetBSD Foundation, Inc.
@@ -31,7 +31,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: bus_space.c,v 1.34 2012/07/18 17:41:59 matt Exp $);
+__KERNEL_RCSID(0, $NetBSD: bus_space.c,v 1.35 2013/04/11 18:20:33 macallan Exp $);
 
 #define _POWERPC_BUS_SPACE_PRIVATE
 
@@ -598,20 +598,6 @@ memio_map(bus_space_tag_t t, bus_addr_t 
 	}
 #endif /* defined (PPC_OEA) || defined(PPC_OEA601) */
 
-	if (t-pbs_extent != NULL) {
-#if !defined(PPC_IBM4XX)
-		if (extent_flags == 0) {
-			extent_free(t-pbs_extent, bpa, size, EX_NOWAIT);
-#ifdef DEBUG
-			printf(bus_space_map(%p[%x:%x], %#x, %#x)
-			 failed: ENOMEM\n,
-			t, t-pbs_base, t-pbs_limit, bpa, size);
-#endif
-			return (ENOMEM);
-		}
-#endif
-	}
-
 	/*
 	 * Map this into the kernel pmap.
 	 */



CVS commit: src/sys/arch/macppc/macppc

2013-04-11 Thread Michael Lorenz
Module Name:src
Committed By:   macallan
Date:   Thu Apr 11 18:36:44 UTC 2013

Modified Files:
src/sys/arch/macppc/macppc: locore.S

Log Message:
more OEA64_BRIDGE support
from Phileas Fogg


To generate a diff of this commit:
cvs rdiff -u -r1.70 -r1.71 src/sys/arch/macppc/macppc/locore.S

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/macppc/macppc/locore.S
diff -u src/sys/arch/macppc/macppc/locore.S:1.70 src/sys/arch/macppc/macppc/locore.S:1.71
--- src/sys/arch/macppc/macppc/locore.S:1.70	Mon Jun 20 19:56:12 2011
+++ src/sys/arch/macppc/macppc/locore.S	Thu Apr 11 18:36:44 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: locore.S,v 1.70 2011/06/20 19:56:12 matt Exp $	*/
+/*	$NetBSD: locore.S,v 1.71 2013/04/11 18:36:44 macallan Exp $	*/
 
 /*
  * Copyright (C) 1995, 1996 Wolfgang Solfrank.
@@ -87,6 +87,11 @@ __start:
 
 	li	0,0
 	mtmsr	0			/* Disable FPU/MMU/exceptions */
+#if defined(PMAP_OEA64_BRIDGE)
+	mfmsr	0			/* Clear SF and ISF bits */
+	clrldi	0,0,3
+	mtmsrd	0
+#endif /* PMAP_OEA64_BRIDGE */
 	isync
 
 /* compute end of kernel memory */



CVS commit: src/gnu/dist/bc/bc

2013-04-11 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Apr 11 19:00:41 UTC 2013

Modified Files:
src/gnu/dist/bc/bc: scan.l

Log Message:
fix argument passing.


To generate a diff of this commit:
cvs rdiff -u -r1.3 -r1.4 src/gnu/dist/bc/bc/scan.l

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/gnu/dist/bc/bc/scan.l
diff -u src/gnu/dist/bc/bc/scan.l:1.3 src/gnu/dist/bc/bc/scan.l:1.4
--- src/gnu/dist/bc/bc/scan.l:1.3	Sun Jan  7 23:03:30 2001
+++ src/gnu/dist/bc/bc/scan.l	Thu Apr 11 15:00:41 2013
@@ -80,10 +80,7 @@ null_prompt (EditLine *el)
 */
 
 static void
-bcel_input (buf, result, max)
-	char *buf;
-	int  *result;
-	int   max;
+bcel_input (char *buf, yy_size_t *result, int max)
 {
   if (!edit || yyin != stdin)
 {



CVS commit: src/lib

2013-04-11 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Apr 11 19:06:04 UTC 2013

Modified Files:
src/lib: Makefile

Log Message:
build libevent later.


To generate a diff of this commit:
cvs rdiff -u -r1.198 -r1.199 src/lib/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/Makefile
diff -u src/lib/Makefile:1.198 src/lib/Makefile:1.199
--- src/lib/Makefile:1.198	Sat Feb 16 16:40:06 2013
+++ src/lib/Makefile	Thu Apr 11 15:06:04 2013
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.198 2013/02/16 21:40:06 jmmv Exp $
+#	$NetBSD: Makefile,v 1.199 2013/04/11 19:06:04 christos Exp $
 #	from: @(#)Makefile	5.25.1.1 (Berkeley) 5/7/91
 
 .include bsd.own.mk
@@ -64,7 +64,6 @@ SUBDIR+=	../external/bsd/flex/lib
 SUBDIR+=	../external/bsd/tre/lib
 SUBDIR+=	../external/bsd/libdwarf/lib
 SUBDIR+=	../external/bsd/libelf/lib
-SUBDIR+=	../external/bsd/libevent/lib
 SUBDIR+=	../external/bsd/liblzf/lib
 SUBDIR+=	../external/bsd/libpcap/lib
 
@@ -175,6 +174,7 @@ SUBDIR+=	../crypto/external/bsd/openssh/
 SUBDIR+=	../crypto/external/bsd/netpgp/lib  # depends on libcrypto, ...
 .endif
 
+SUBDIR+=	../external/bsd/libevent/lib	# depends on libcrypto
 SUBDIR+=	../external/bsd/bind/lib	# depends on libcrypto
 SUBDIR+=	../external/bsd/fetch/lib	# depends on libssl
 



CVS commit: src/etc

2013-04-11 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Thu Apr 11 19:13:47 UTC 2013

Modified Files:
src/etc: MAKEDEV.tmpl

Log Message:
Add a makedisk_p12high, used by VAX now after unbumping MAXPARTITIONS from
16 down to 12.


To generate a diff of this commit:
cvs rdiff -u -r1.165 -r1.166 src/etc/MAKEDEV.tmpl

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/etc/MAKEDEV.tmpl
diff -u src/etc/MAKEDEV.tmpl:1.165 src/etc/MAKEDEV.tmpl:1.166
--- src/etc/MAKEDEV.tmpl:1.165	Fri Mar  8 12:33:25 2013
+++ src/etc/MAKEDEV.tmpl	Thu Apr 11 19:13:46 2013
@@ -1,5 +1,5 @@
 #!/bin/sh -
-#	$NetBSD: MAKEDEV.tmpl,v 1.165 2013/03/08 12:33:25 jmcneill Exp $
+#	$NetBSD: MAKEDEV.tmpl,v 1.166 2013/04/11 19:13:46 martin Exp $
 #
 # Copyright (c) 2003,2007,2008 The NetBSD Foundation, Inc.
 # All rights reserved.
@@ -2162,6 +2162,37 @@ makedisk_p8()
 	mkdev r${name}${unit}h	c $chr $(($unit * 8 + 7))	640 $g_operator
 }
 
+makedisk_p12high()
+{
+	ho=524280	# offset for partition 9 to 11 (same as ...p16high)
+	name=$1; unit=$2; blk=$3; chr=$4
+
+	mkdev ${name}${unit}a	b $blk $(($unit * 8 + 0))	640 $g_operator
+	mkdev ${name}${unit}b	b $blk $(($unit * 8 + 1))	640 $g_operator
+	mkdev ${name}${unit}c	b $blk $(($unit * 8 + 2))	640 $g_operator
+	mkdev ${name}${unit}d	b $blk $(($unit * 8 + 3))	640 $g_operator
+	mkdev ${name}${unit}e	b $blk $(($unit * 8 + 4))	640 $g_operator
+	mkdev ${name}${unit}f	b $blk $(($unit * 8 + 5))	640 $g_operator
+	mkdev ${name}${unit}g	b $blk $(($unit * 8 + 6))	640 $g_operator
+	mkdev ${name}${unit}h	b $blk $(($unit * 8 + 7))	640 $g_operator
+	mkdev ${name}${unit}i	b $blk $(($unit * 8 + $ho + 8)) 640 $g_operator
+	mkdev ${name}${unit}j	b $blk $(($unit * 8 + $ho + 9)) 640 $g_operator
+	mkdev ${name}${unit}k	b $blk $(($unit * 8 + $ho + 10)) 640 $g_operator
+	mkdev ${name}${unit}l	b $blk $(($unit * 8 + $ho + 11)) 640 $g_operator
+	mkdev r${name}${unit}a	c $chr $(($unit * 8 + 0))	640 $g_operator
+	mkdev r${name}${unit}b	c $chr $(($unit * 8 + 1))	640 $g_operator
+	mkdev r${name}${unit}c	c $chr $(($unit * 8 + 2))	640 $g_operator
+	mkdev r${name}${unit}d	c $chr $(($unit * 8 + 3))	640 $g_operator
+	mkdev r${name}${unit}e	c $chr $(($unit * 8 + 4))	640 $g_operator
+	mkdev r${name}${unit}f	c $chr $(($unit * 8 + 5))	640 $g_operator
+	mkdev r${name}${unit}g	c $chr $(($unit * 8 + 6))	640 $g_operator
+	mkdev r${name}${unit}h	c $chr $(($unit * 8 + 7))	640 $g_operator
+	mkdev r${name}${unit}i	c $chr $(($unit * 8 + $ho + 8)) 640 $g_operator
+	mkdev r${name}${unit}j	c $chr $(($unit * 8 + $ho + 9)) 640 $g_operator
+	mkdev r${name}${unit}k	c $chr $(($unit * 8 + $ho + 10)) 640 $g_operator
+	mkdev r${name}${unit}l	c $chr $(($unit * 8 + $ho + 11)) 640 $g_operator
+}
+
 makedisk_p16()
 {
 	name=$1; unit=$2; blk=$3; chr=$4



CVS commit: src/sys/arch/powerpc/powerpc

2013-04-11 Thread Michael Lorenz
Module Name:src
Committed By:   macallan
Date:   Thu Apr 11 19:53:51 UTC 2013

Modified Files:
src/sys/arch/powerpc/powerpc: ofw_machdep.c

Log Message:
KNF nits


To generate a diff of this commit:
cvs rdiff -u -r1.20 -r1.21 src/sys/arch/powerpc/powerpc/ofw_machdep.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/powerpc/powerpc/ofw_machdep.c
diff -u src/sys/arch/powerpc/powerpc/ofw_machdep.c:1.20 src/sys/arch/powerpc/powerpc/ofw_machdep.c:1.21
--- src/sys/arch/powerpc/powerpc/ofw_machdep.c:1.20	Mon Apr  1 20:14:42 2013
+++ src/sys/arch/powerpc/powerpc/ofw_machdep.c	Thu Apr 11 19:53:51 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: ofw_machdep.c,v 1.20 2013/04/01 20:14:42 macallan Exp $	*/
+/*	$NetBSD: ofw_machdep.c,v 1.21 2013/04/11 19:53:51 macallan Exp $	*/
 
 /*
  * Copyright (C) 1996 Wolfgang Solfrank.
@@ -32,7 +32,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: ofw_machdep.c,v 1.20 2013/04/01 20:14:42 macallan Exp $);
+__KERNEL_RCSID(0, $NetBSD: ofw_machdep.c,v 1.21 2013/04/11 19:53:51 macallan Exp $);
 
 #include sys/param.h
 #include sys/buf.h
@@ -99,13 +99,13 @@ mem_regions(struct mem_region **memp, st
 		goto error;
 
 	/* how many mem regions did we get? */
-	numregs = regcnt / (sizeof(uint32_t)*(acells+scells));
+	numregs = regcnt / (sizeof(uint32_t) * (acells + scells));
 	DPRINTF(regcnt=%d num=%d acell=%d scell=%d\n,
 	regcnt, numregs, acells, scells);
 
 	/* move the data into OFmem */
 	memset(OFmem, 0, sizeof(OFmem));
-	for (i=0, cnt=0; i = numregs; i++) {
+	for (i = 0, cnt = 0; i = numregs; i++) {
 		uint64_t addr, size;
 
 		if (acells  1)
@@ -168,7 +168,7 @@ mem_regions(struct mem_region **memp, st
 
 	/* move the data into OFavail */
 	memset(OFavail, 0, sizeof(OFavail));
-	for (i=0, cnt=0; i = numregs; i++) {
+	for (i = 0, cnt = 0; i = numregs; i++) {
 		uint64_t addr, size;
 
 		DPRINTF(%d\n, i);
@@ -188,7 +188,7 @@ mem_regions(struct mem_region **memp, st
 			continue;
 #ifndef _LP64
 		if (addr  0x || size  0x ||
-			(addr+size)  0x) {
+			(addr + size)  0x) {
 			aprint_error(Base addr of %llx or size of %llx too
 			 large for 32 bit OS. Skipping., addr, size);
 			continue;



CVS commit: src/sys/arch/powerpc/powerpc

2013-04-11 Thread Michael Lorenz
Module Name:src
Committed By:   macallan
Date:   Thu Apr 11 19:55:10 UTC 2013

Modified Files:
src/sys/arch/powerpc/powerpc: ofw_machdep.c

Log Message:
fix off-by-one
noticed by Phileas Fogg


To generate a diff of this commit:
cvs rdiff -u -r1.21 -r1.22 src/sys/arch/powerpc/powerpc/ofw_machdep.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/powerpc/powerpc/ofw_machdep.c
diff -u src/sys/arch/powerpc/powerpc/ofw_machdep.c:1.21 src/sys/arch/powerpc/powerpc/ofw_machdep.c:1.22
--- src/sys/arch/powerpc/powerpc/ofw_machdep.c:1.21	Thu Apr 11 19:53:51 2013
+++ src/sys/arch/powerpc/powerpc/ofw_machdep.c	Thu Apr 11 19:55:10 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: ofw_machdep.c,v 1.21 2013/04/11 19:53:51 macallan Exp $	*/
+/*	$NetBSD: ofw_machdep.c,v 1.22 2013/04/11 19:55:10 macallan Exp $	*/
 
 /*
  * Copyright (C) 1996 Wolfgang Solfrank.
@@ -32,7 +32,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: ofw_machdep.c,v 1.21 2013/04/11 19:53:51 macallan Exp $);
+__KERNEL_RCSID(0, $NetBSD: ofw_machdep.c,v 1.22 2013/04/11 19:55:10 macallan Exp $);
 
 #include sys/param.h
 #include sys/buf.h
@@ -105,7 +105,7 @@ mem_regions(struct mem_region **memp, st
 
 	/* move the data into OFmem */
 	memset(OFmem, 0, sizeof(OFmem));
-	for (i = 0, cnt = 0; i = numregs; i++) {
+	for (i = 0, cnt = 0; i  numregs; i++) {
 		uint64_t addr, size;
 
 		if (acells  1)
@@ -168,7 +168,7 @@ mem_regions(struct mem_region **memp, st
 
 	/* move the data into OFavail */
 	memset(OFavail, 0, sizeof(OFavail));
-	for (i = 0, cnt = 0; i = numregs; i++) {
+	for (i = 0, cnt = 0; i  numregs; i++) {
 		uint64_t addr, size;
 
 		DPRINTF(%d\n, i);



CVS commit: src/external/bsd/libevent/dist/test

2013-04-11 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Apr 11 20:14:44 UTC 2013

Modified Files:
src/external/bsd/libevent/dist/test: regress.c regress_dns.c

Log Message:
fix merge that broke the tests


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 src/external/bsd/libevent/dist/test/regress.c
cvs rdiff -u -r1.3 -r1.4 src/external/bsd/libevent/dist/test/regress_dns.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/libevent/dist/test/regress.c
diff -u src/external/bsd/libevent/dist/test/regress.c:1.5 src/external/bsd/libevent/dist/test/regress.c:1.6
--- src/external/bsd/libevent/dist/test/regress.c:1.5	Thu Apr 11 12:56:42 2013
+++ src/external/bsd/libevent/dist/test/regress.c	Thu Apr 11 16:14:44 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: regress.c,v 1.5 2013/04/11 16:56:42 christos Exp $	*/
+/*	$NetBSD: regress.c,v 1.6 2013/04/11 20:14:44 christos Exp $	*/
 /*
  * Copyright (c) 2003-2007 Niels Provos pro...@citi.umich.edu
  * Copyright (c) 2007-2012 Niels Provos and Nick Mathewson
@@ -33,7 +33,7 @@
 
 #include event2/event-config.h
 #include sys/cdefs.h
-__RCSID($NetBSD: regress.c,v 1.5 2013/04/11 16:56:42 christos Exp $);
+__RCSID($NetBSD: regress.c,v 1.6 2013/04/11 20:14:44 christos Exp $);
 
 #include sys/types.h
 #include sys/stat.h
@@ -580,7 +580,6 @@ end:
 	cleanup_test();
 }
 
-#if 0
 static void
 test_simpletimeout(void)
 {
@@ -599,7 +598,6 @@ test_simpletimeout(void)
 
 	cleanup_test();
 }
-#endif
 
 static void
 periodic_timeout_cb(evutil_socket_t fd, short event, void *arg)

Index: src/external/bsd/libevent/dist/test/regress_dns.c
diff -u src/external/bsd/libevent/dist/test/regress_dns.c:1.3 src/external/bsd/libevent/dist/test/regress_dns.c:1.4
--- src/external/bsd/libevent/dist/test/regress_dns.c:1.3	Thu Apr 11 12:56:42 2013
+++ src/external/bsd/libevent/dist/test/regress_dns.c	Thu Apr 11 16:14:44 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: regress_dns.c,v 1.3 2013/04/11 16:56:42 christos Exp $	*/
+/*	$NetBSD: regress_dns.c,v 1.4 2013/04/11 20:14:44 christos Exp $	*/
 /*
  * Copyright (c) 2003-2007 Niels Provos pro...@citi.umich.edu
  * Copyright (c) 2007-2012 Niels Provos and Nick Mathewson
@@ -34,7 +34,7 @@
 
 #include event2/event-config.h
 #include sys/cdefs.h
-__RCSID($NetBSD: regress_dns.c,v 1.3 2013/04/11 16:56:42 christos Exp $);
+__RCSID($NetBSD: regress_dns.c,v 1.4 2013/04/11 20:14:44 christos Exp $);
 
 #include sys/types.h
 #include sys/stat.h
@@ -79,10 +79,8 @@ __RCSID($NetBSD: regress_dns.c,v 1.3 20
 static int dns_ok = 0;
 static int dns_got_cancel = 0;
 static int dns_err = 0;
-#endif
 
 
-#if 0
 static void
 dns_gethostbyname_cb(int result, char type, int count, int ttl,
 void *addresses, void *arg)
@@ -223,7 +221,6 @@ end:
 	if (base)
 		event_base_free(base);
 }
-#endif
 
 static int n_server_responses = 0;
 



CVS commit: src/distrib/sets/lists/comp

2013-04-11 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Apr 12 00:30:58 UTC 2013

Modified Files:
src/distrib/sets/lists/comp: md.amd64 mi

Log Message:
more libevent set fixes


To generate a diff of this commit:
cvs rdiff -u -r1.192 -r1.193 src/distrib/sets/lists/comp/md.amd64
cvs rdiff -u -r1.1814 -r1.1815 src/distrib/sets/lists/comp/mi

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/comp/md.amd64
diff -u src/distrib/sets/lists/comp/md.amd64:1.192 src/distrib/sets/lists/comp/md.amd64:1.193
--- src/distrib/sets/lists/comp/md.amd64:1.192	Thu Apr 11 13:43:17 2013
+++ src/distrib/sets/lists/comp/md.amd64	Thu Apr 11 20:30:56 2013
@@ -1,4 +1,4 @@
-# $NetBSD: md.amd64,v 1.192 2013/04/11 17:43:17 christos Exp $
+# $NetBSD: md.amd64,v 1.193 2013/04/12 00:30:56 christos Exp $
 ./usr/include/amd64comp-c-include
 ./usr/include/amd64/ansi.h			comp-c-include
 ./usr/include/amd64/aout_machdep.h		comp-c-include
@@ -554,7 +554,7 @@
 ./usr/lib/i386/libevent_pic.a			comp-c-piclib		compat,pic
 ./usr/lib/i386/libevent_openssl.a		comp-c-lib		compat,crypto
 ./usr/lib/i386/libevent_openssl.so		comp-sys-shlib		compat,pic,crypto
-./usr/lib/i386/libevent_openssl_.a		comp-c-proflib		compat,profile,crypto
+./usr/lib/i386/libevent_openssl_p.a		comp-c-proflib		compat,profile,crypto
 ./usr/lib/i386/libevent_openssl_pic.a		comp-c-piclib		compat,pic,crypto
 ./usr/lib/i386/libevent_pthreads.a		comp-c-lib		compat
 ./usr/lib/i386/libevent_pthreads.so		comp-sys-shlib		compat,pic

Index: src/distrib/sets/lists/comp/mi
diff -u src/distrib/sets/lists/comp/mi:1.1814 src/distrib/sets/lists/comp/mi:1.1815
--- src/distrib/sets/lists/comp/mi:1.1814	Thu Apr 11 13:43:17 2013
+++ src/distrib/sets/lists/comp/mi	Thu Apr 11 20:30:57 2013
@@ -1,4 +1,4 @@
-#	$NetBSD: mi,v 1.1814 2013/04/11 17:43:17 christos Exp $
+#	$NetBSD: mi,v 1.1815 2013/04/12 00:30:57 christos Exp $
 #
 # Note: don't delete entries from here - mark them as obsolete instead.
 #
@@ -2829,8 +2829,8 @@
 ./usr/lib/libevent_p.acomp-c-proflib		profile
 ./usr/lib/libevent_openssl.a			comp-c-lib		crypto
 ./usr/lib/libevent_openssl_p.a			comp-c-proflib		profile,crypto
-./usr/lib/libevent_pthread.a			comp-c-lib
-./usr/lib/libevent_pthread_p.a			comp-c-proflib		profile
+./usr/lib/libevent_pthreads.a			comp-c-lib
+./usr/lib/libevent_pthreads_p.a			comp-c-proflib		profile
 ./usr/lib/libexecinfo.acomp-c-lib
 ./usr/lib/libexecinfo_p.a			comp-c-proflib		profile
 ./usr/lib/libexpat.acomp-c-lib
@@ -3247,6 +3247,8 @@
 ./usr/libdata/lint/llib-ledit.ln		comp-c-lintlib		lint
 ./usr/libdata/lint/llib-lelf.ln			comp-c-lintlib		lint
 ./usr/libdata/lint/llib-levent.ln		comp-c-lintlib		lint
+./usr/libdata/lint/llib-levent_openssl.ln	comp-c-lintlib		lint,crypto
+./usr/libdata/lint/llib-levent_pthreads.ln	comp-c-lintlib		lint
 ./usr/libdata/lint/llib-lexecinfo.ln		comp-c-lintlib		lint
 ./usr/libdata/lint/llib-lexpat.ln		comp-c-lintlib		lint
 ./usr/libdata/lint/llib-lfetch.ln		comp-c-lintlib		lint
@@ -7995,11 +7997,11 @@
 ./usr/share/man/cat3/sigismember.0		comp-c-catman		.cat
 ./usr/share/man/cat3/siglongjmp.0		comp-c-catman		.cat
 ./usr/share/man/cat3/signal.0			comp-c-catman		.cat
-./usr/share/man/cat3/signal_add.0		comp-c-catman		.cat
-./usr/share/man/cat3/signal_del.0		comp-c-catman		.cat
-./usr/share/man/cat3/signal_initialized.0	comp-c-catman		.cat
-./usr/share/man/cat3/signal_pending.0		comp-c-catman		.cat
-./usr/share/man/cat3/signal_set.0		comp-c-catman		.cat
+./usr/share/man/cat3/signal_add.0		comp-obsolete		obsolete
+./usr/share/man/cat3/signal_del.0		comp-obsolete		obsolete
+./usr/share/man/cat3/signal_initialized.0	comp-obsolete		obsolete
+./usr/share/man/cat3/signal_pending.0		comp-obsolete		obsolete
+./usr/share/man/cat3/signal_set.0		comp-obsolete		obsolete
 ./usr/share/man/cat3/signbit.0			comp-c-catman		.cat
 ./usr/share/man/cat3/significand.0		comp-c-catman		.cat
 ./usr/share/man/cat3/significandf.0		comp-c-catman		.cat
@@ -11898,80 +11900,80 @@
 ./usr/share/man/html3/ether_ntohost.html	comp-c-htmlman		html
 ./usr/share/man/html3/ethers.html		comp-c-htmlman		html
 ./usr/share/man/html3/evasprintf.html		comp-c-htmlman		html
-./usr/share/man/man3/evbuffer.html		comp-c-htmlman		html
-./usr/share/man/man3/evbuffer_add.html		comp-obsolete		obsolete
-./usr/share/man/man3/evbuffer_add_buffer.html	comp-obsolete		obsolete
-./usr/share/man/man3/evbuffer_add_printf.html	comp-obsolete		obsolete
-./usr/share/man/man3/evbuffer_add_vprintf.html	comp-obsolete		obsolete
-./usr/share/man/man3/evbuffer_cb_info.html	comp-c-htmlman		html
-./usr/share/man/man3/evbuffer_compat.html	comp-c-htmlman		html
-./usr/share/man/man3/evbuffer_drain.html	comp-obsolete		obsolete
-./usr/share/man/man3/evbuffer_find.html		comp-obsolete		obsolete
-./usr/share/man/man3/evbuffer_free.html		comp-obsolete		obsolete
-./usr/share/man/man3/evbuffer_iovec.html	comp-c-htmlman		html

CVS commit: src/distrib/sets/lists/comp

2013-04-11 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Apr 12 00:55:13 UTC 2013

Modified Files:
src/distrib/sets/lists/comp: mi

Log Message:
one more mistake


To generate a diff of this commit:
cvs rdiff -u -r1.1815 -r1.1816 src/distrib/sets/lists/comp/mi

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/comp/mi
diff -u src/distrib/sets/lists/comp/mi:1.1815 src/distrib/sets/lists/comp/mi:1.1816
--- src/distrib/sets/lists/comp/mi:1.1815	Thu Apr 11 20:30:57 2013
+++ src/distrib/sets/lists/comp/mi	Thu Apr 11 20:55:12 2013
@@ -1,4 +1,4 @@
-#	$NetBSD: mi,v 1.1815 2013/04/12 00:30:57 christos Exp $
+#	$NetBSD: mi,v 1.1816 2013/04/12 00:55:12 christos Exp $
 #
 # Note: don't delete entries from here - mark them as obsolete instead.
 #
@@ -11916,6 +11916,7 @@
 ./usr/share/man/html3/evbuffer_read.html		comp-obsolete		obsolete
 ./usr/share/man/html3/evbuffer_readline.html	comp-obsolete		obsolete
 ./usr/share/man/html3/evbuffer_write.html	comp-obsolete		obsolete
+./usr/share/man/html3/evdeprecated.html		comp-c-htmlman		html
 ./usr/share/man/html3/evdns.html			comp-c-htmlman		html
 ./usr/share/man/html3/evdns_clear_nameservers_and_suspend.html	comp-obsolete	obsolete
 ./usr/share/man/html3/evdns_compat.html		comp-c-htmlman		html



CVS commit: src/sys/dev/pci

2013-04-11 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Fri Apr 12 03:32:28 UTC 2013

Modified Files:
src/sys/dev/pci: pcireg.h

Log Message:
Add comments for some PCI Express  Capability registers.


To generate a diff of this commit:
cvs rdiff -u -r1.76 -r1.77 src/sys/dev/pci/pcireg.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/pci/pcireg.h
diff -u src/sys/dev/pci/pcireg.h:1.76 src/sys/dev/pci/pcireg.h:1.77
--- src/sys/dev/pci/pcireg.h:1.76	Sun Mar  3 20:10:47 2013
+++ src/sys/dev/pci/pcireg.h	Fri Apr 12 03:32:28 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: pcireg.h,v 1.76 2013/03/03 20:10:47 msaitoh Exp $	*/
+/*	$NetBSD: pcireg.h,v 1.77 2013/04/12 03:32:28 msaitoh Exp $	*/
 
 /*
  * Copyright (c) 1995, 1996, 1999, 2000
@@ -654,7 +654,7 @@ struct pci_msix_table_entry {
 #define PCI_PCIE_DCSR_NFED	__BIT(1 + 16)
 #define PCI_PCIE_DCSR_FED	__BIT(2 + 16)
 #define PCI_PCIE_DCSR_URD	__BIT(3 + 16)
-#define PCI_PCIE_LCAP		0x0c
+#define PCI_PCIE_LCAP		0x0c	/* Link Capabilities Register */
 #define PCI_PCIE_LCSR		0x10	/* Link Control  Status Register */
 #define PCI_PCIE_LCSR_ASPM_L0S	__BIT(0)
 #define PCI_PCIE_LCSR_ASPM_L1	__BIT(1)
@@ -679,7 +679,7 @@ struct pci_msix_table_entry {
 #define PCI_PCIE_SLCAP_PIP	__BIT(4)	/* Power Indicator Present */
 #define PCI_PCIE_SLCAP_HPS	__BIT(5)	/* Hot-Plug Surprise */
 #define PCI_PCIE_SLCAP_HPC	__BIT(6)	/* Hot-Plug Capable */
-#define PCI_PCIE_SLCSR		0x18
+#define PCI_PCIE_SLCSR		0x18	/* Slot Control  Status Register */
 #define PCI_PCIE_SLCSR_ABE	__BIT(0)
 #define PCI_PCIE_SLCSR_PFE	__BIT(1)
 #define PCI_PCIE_SLCSR_MSE	__BIT(2)
@@ -694,14 +694,14 @@ struct pci_msix_table_entry {
 #define PCI_PCIE_SLCSR_MS	__BIT(5 + 16)
 #define PCI_PCIE_SLCSR_PDS	__BIT(6 + 16)
 #define PCI_PCIE_SLCSR_LACS	__BIT(8 + 16)
-#define PCI_PCIE_RCR		0x1c
-#define PCI_PCIE_RSR		0x20
-#define PCI_PCIE_DCAP2		0x24
-#define PCI_PCIE_DCSR2		0x28
-#define PCI_PCIE_LCAP2		0x2c
-#define PCI_PCIE_LCSR2		0x30
-#define PCI_PCIE_SLCAP2		0x34
-#define PCI_PCIE_SLCSR2		0x38
+#define PCI_PCIE_RCR		0x1c	/* Root Control  Capabilities Reg. */
+#define PCI_PCIE_RSR		0x20	/* Root Status Register */
+#define PCI_PCIE_DCAP2		0x24	/* Device Capabilities 2 Register */
+#define PCI_PCIE_DCSR2		0x28	/* Device Control  Status 2 Reg. */
+#define PCI_PCIE_LCAP2		0x2c	/* Link Capabilities 2 Register */
+#define PCI_PCIE_LCSR2		0x30	/* Link Control  Status 2 Register */
+#define PCI_PCIE_SLCAP2		0x34	/* Slot Capabilities 2 Register */
+#define PCI_PCIE_SLCSR2		0x38	/* Slot Control  Status 2 Register */
 
 /*
  * Interrupt Configuration Register; contains interrupt pin and line.



CVS commit: src/sys/dev/pci

2013-04-11 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Fri Apr 12 03:33:17 UTC 2013

Modified Files:
src/sys/dev/pci: if_bge.c

Log Message:
Cleanup. No functional change.


To generate a diff of this commit:
cvs rdiff -u -r1.236 -r1.237 src/sys/dev/pci/if_bge.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/pci/if_bge.c
diff -u src/sys/dev/pci/if_bge.c:1.236 src/sys/dev/pci/if_bge.c:1.237
--- src/sys/dev/pci/if_bge.c:1.236	Thu Apr 11 11:24:07 2013
+++ src/sys/dev/pci/if_bge.c	Fri Apr 12 03:33:17 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_bge.c,v 1.236 2013/04/11 11:24:07 msaitoh Exp $	*/
+/*	$NetBSD: if_bge.c,v 1.237 2013/04/12 03:33:17 msaitoh Exp $	*/
 
 /*
  * Copyright (c) 2001 Wind River Systems
@@ -79,7 +79,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: if_bge.c,v 1.236 2013/04/11 11:24:07 msaitoh Exp $);
+__KERNEL_RCSID(0, $NetBSD: if_bge.c,v 1.237 2013/04/12 03:33:17 msaitoh Exp $);
 
 #include vlan.h
 
@@ -184,7 +184,7 @@ static int bge_rxthresh_nodenum;
 
 typedef int (*bge_eaddr_fcn_t)(struct bge_softc *, uint8_t[]);
 
-static uint32_t bge_chipid(const struct pci_attach_args *pa);
+static uint32_t bge_chipid(const struct pci_attach_args *);
 static int bge_probe(device_t, cfdata_t, void *);
 static void bge_attach(device_t, device_t, void *);
 static int bge_detach(device_t, int);
@@ -4156,7 +4156,7 @@ bge_reset(struct bge_softc *sc)
 	}
 
 	/* 57XX step 18 */
-	/* Wirte mac mode. 
+	/* Write mac mode. 
 	 * XXX Write 0x0c for 5703S and 5704S
 	 */
 	val = CSR_READ_4(sc, BGE_MAC_MODE);
Index: src/sys/dev/pci/if_bge.c
diff -u src/sys/dev/pci/if_bge.c:1.235 src/sys/dev/pci/if_bge.c:1.236
--- src/sys/dev/pci/if_bge.c:1.235	Mon Apr  8 15:55:58 2013
+++ src/sys/dev/pci/if_bge.c	Thu Apr 11 11:24:07 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_bge.c,v 1.235 2013/04/08 15:55:58 msaitoh Exp $	*/
+/*	$NetBSD: if_bge.c,v 1.236 2013/04/11 11:24:07 msaitoh Exp $	*/
 
 /*
  * Copyright (c) 2001 Wind River Systems
@@ -79,7 +79,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: if_bge.c,v 1.235 2013/04/08 15:55:58 msaitoh Exp $);
+__KERNEL_RCSID(0, $NetBSD: if_bge.c,v 1.236 2013/04/11 11:24:07 msaitoh Exp $);
 
 #include vlan.h
 
@@ -2491,8 +2491,9 @@ bge_blockinit(struct bge_softc *sc)
 	 */
 	pci_conf_write(sc-sc_pc, sc-sc_pcitag, BGE_PCI_MEMWIN_BASEADDR, 0);
 
-	/* Step 33: Configure mbuf memory pool */
 	if (!BGE_IS_5705_PLUS(sc)) {
+		/* 57XX step 33 */
+		/* Configure mbuf memory pool */
 		CSR_WRITE_4(sc, BGE_BMAN_MBUFPOOL_BASEADDR,
 		BGE_BUFFPOOL_1);
 
@@ -2501,14 +2502,18 @@ bge_blockinit(struct bge_softc *sc)
 		else
 			CSR_WRITE_4(sc, BGE_BMAN_MBUFPOOL_LEN, 0x18000);
 
+		/* 57XX step 34 */
 		/* Configure DMA resource pool */
 		CSR_WRITE_4(sc, BGE_BMAN_DMA_DESCPOOL_BASEADDR,
 		BGE_DMA_DESCRIPTORS);
 		CSR_WRITE_4(sc, BGE_BMAN_DMA_DESCPOOL_LEN, 0x2000);
 	}
 
 	/* Step 35: Configure mbuf pool watermarks */
 	/* new broadcom docs strongly recommend these: */
 	if (BGE_IS_5717_PLUS(sc)) {
 		CSR_WRITE_4(sc, BGE_BMAN_MBUFPOOL_READDMA_LOWAT, 0x0);
 		CSR_WRITE_4(sc, BGE_BMAN_MBUFPOOL_MACRX_LOWAT, 0x2a);
@@ -2529,11 +2534,13 @@ bge_blockinit(struct bge_softc *sc)
 		CSR_WRITE_4(sc, BGE_BMAN_MBUFPOOL_HIWAT, 0x60);
 	}
 
-	/* Step 36: Configure DMA resource watermarks */
+	/* 57XX step 36 */
+	/* Configure DMA resource watermarks */
 	CSR_WRITE_4(sc, BGE_BMAN_DMA_DESCPOOL_LOWAT, 5);
 	CSR_WRITE_4(sc, BGE_BMAN_DMA_DESCPOOL_HIWAT, 10);
 
-	/* Step 38: Enable buffer manager */
+	/* 5718 step 13, 57XX step 38 */
+	/* Enable buffer manager */
 	val = BGE_BMANMODE_ENABLE | BGE_BMANMODE_ATTN;
 	/*
 	 * Change the arbitration algorithm of TXMBUF read request to
@@ -2549,7 +2556,8 @@ bge_blockinit(struct bge_softc *sc)
 		val |= BGE_BMANMODE_LOMBUF_ATTN;
 	CSR_WRITE_4(sc, BGE_BMAN_MODE, val);
 
-	/* Step 39: Poll for buffer manager start indication */
+	/* 57XX step 39 */
+	/* Poll for buffer manager start indication */
 	for (i = 0; i  BGE_TIMEOUT * 2; i++) {
 		DELAY(10);
 		if (CSR_READ_4(sc, BGE_BMAN_MODE)  BGE_BMANMODE_ENABLE)
@@ -2562,7 +2570,8 @@ bge_blockinit(struct bge_softc *sc)
 		return ENXIO;
 	}
 
-	/* Step 40: Enable flow-through queues */
+	/* 57XX step 40 */
+	/* Enable flow-through queues */
 	CSR_WRITE_4(sc, BGE_FTQ_RESET, 0x);
 	CSR_WRITE_4(sc, BGE_FTQ_RESET, 0);
 
@@ -2610,9 +2619,11 @@ bge_blockinit(struct bge_softc *sc)
 	 *   the controller support multiple send rings.
 	 */
 
-	/* Step 41: Initialize the standard RX ring control block */
+	/* 5718 step 15, 57XX step 41 */
+	/* Initialize the standard RX ring control block */
 	rcb = sc-bge_rdata-bge_info.bge_std_rx_rcb;
 	BGE_HOSTADDR(rcb-bge_hostaddr, BGE_RING_DMA_ADDR(sc, bge_rx_std_ring));
+	/* 5718 step 16 */
 	if (BGE_IS_5717_PLUS(sc)) {
 		/*
 		 * Bits 31-16: Programmable ring size (2048, 1024, 512, .., 32)
@@ -2656,8 +2667,9 @@ bge_blockinit(struct bge_softc *sc)
 	/* Reset the standard receive producer ring producer index. */
 	bge_writembx(sc, BGE_MBX_RX_STD_PROD_LO, 0);
 
+	/* 57XX step 42 */
 	/*
-	 * Step 42: Initialize the jumbo RX ring control block
+	 * Initialize the jumbo RX ring control block
 	 * We set the 'ring disabled' bit in the flags
 	 * field until we're actually ready to start
 	 * using this ring (i.e. once we set the MTU
@@ -2687,6 +2699,7 @@ bge_blockinit(struct bge_softc *sc)
 		bge_writembx(sc, BGE_MBX_RX_JUMBO_PROD_LO, 0);
 	}
 
+	/* 57XX step 43 */
 	/* Disable the mini receive producer ring RCB. */
 	if (BGE_IS_5700_FAMILY(sc)) {
 		/* Set up dummy disabled mini ring RCB */
@@ -2712,6 +2725,7 @@ bge_blockinit(struct bge_softc *sc)
 			CSR_WRITE_4(sc, BGE_ISO_PKT_TX,
 			(CSR_READ_4(sc, BGE_ISO_PKT_TX)  ~3) | 2);
 	}
+	/* 5718 step 14, 57XX step 44 */
 	/*
 	 * The BD ring replenish thresholds control how often the
 	 * hardware fetches new BD's from the producer rings in host
@@ -2729,11 +2743,13 @@ bge_blockinit(struct bge_softc *sc)
 	if (BGE_IS_JUMBO_CAPABLE(sc))
 		CSR_WRITE_4(sc, 
@@ -2501,14 +2502,18 @@ bge_blockinit(struct bge_softc *sc)
 	}
 
-	/* Step 35: Configure mbuf pool watermarks */
-	/* new broadcom docs strongly recommend these: */
+	/* 5718 step 11, 57XX step 35 */
+	/*
+	 * Configure mbuf pool watermarks. New broadcom docs strongly
+	 * recommend these.
+	 */
 	if (BGE_IS_5717_PLUS(sc)) {
 		CSR_WRITE_4(sc, BGE_BMAN_MBUFPOOL_READDMA_LOWAT, 0x0);

CVS commit: src/sys/arch/m68k/fpe

2013-04-11 Thread Tetsuya Isaki
Module Name:src
Committed By:   isaki
Date:   Thu Apr 11 13:27:11 UTC 2013

Modified Files:
src/sys/arch/m68k/fpe: fpu_emulate.h fpu_hyperb.c fpu_log.c fpu_trig.c

Log Message:
Introduce FPU_CONST_* constants to avoid a magic number.


To generate a diff of this commit:
cvs rdiff -u -r1.22 -r1.23 src/sys/arch/m68k/fpe/fpu_emulate.h
cvs rdiff -u -r1.7 -r1.8 src/sys/arch/m68k/fpe/fpu_hyperb.c
cvs rdiff -u -r1.15 -r1.16 src/sys/arch/m68k/fpe/fpu_log.c
cvs rdiff -u -r1.8 -r1.9 src/sys/arch/m68k/fpe/fpu_trig.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:
